# coding: utf-8
#
# Copyright 2023 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Interface Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.4
# Namespace: com.sun.star.reflection
from __future__ import annotations
import typing
from abc import abstractmethod
from .x_idl_member import XIdlMember as XIdlMember_e3400cfc
if typing.TYPE_CHECKING:
    from .param_info import ParamInfo as ParamInfo_d7210cb0
    from .x_idl_class import XIdlClass as XIdlClass_d63a0c9a
    from com.sun.star.reflection.MethodMode import MethodModeProto  # type: ignore

class XIdlMethod(XIdlMember_e3400cfc):
    """
    Reflects an IDL interface method.

    See Also:
        `API XIdlMethod <https://api.libreoffice.org/docs/idl/ref/interfacecom_1_1sun_1_1star_1_1reflection_1_1XIdlMethod.html>`_
    """
    __ooo_ns__: str = 'com.sun.star.reflection'
    __ooo_full_ns__: str = 'com.sun.star.reflection.XIdlMethod'
    __ooo_type_name__: str = 'interface'
    __pyunointerface__: str = 'com.sun.star.reflection.XIdlMethod'

    @abstractmethod
    def getExceptionTypes(self) -> typing.Tuple[XIdlClass_d63a0c9a, ...]:
        """
        Returns the declared exceptions types of the reflected method.
        """
        ...
    @abstractmethod
    def getMode(self) -> MethodModeProto:
        """
        Returns the method mode in which calls are run, i.e.
        
        either oneway or twoway. Method mode oneway denotes that a call may be run asynchronously (thus having no out parameters or return value)
        """
        ...
    @abstractmethod
    def getParameterInfos(self) -> typing.Tuple[ParamInfo_d7210cb0, ...]:
        """
        Returns formal parameter information of the reflected method in order of IDL declaration.
        
        Parameter information reflects the parameter's access mode (in, out, inout), the parameter's name and formal type.
        """
        ...
    @abstractmethod
    def getParameterTypes(self) -> typing.Tuple[XIdlClass_d63a0c9a, ...]:
        """
        Returns the formal parameter types of the reflected method in order of IDL declaration.
        """
        ...
    @abstractmethod
    def getReturnType(self) -> XIdlClass_d63a0c9a:
        """
        Returns the return type of the reflected method.
        """
        ...
    @abstractmethod
    def invoke(self, obj: object, args: object) -> object:
        """
        Invokes the reflected method on a given object with the given parameters.
        
        The parameters may be widening converted to fit their exact IDL type, meaning no loss of information.

        Raises:
            com.sun.star.lang.IllegalArgumentException: ``IllegalArgumentException``
            com.sun.star.reflection.InvocationTargetException: ``InvocationTargetException``
        """
        ...

__all__ = ['XIdlMethod']



# coding: utf-8
#
# Copyright 2023 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Interface Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.4
# Namespace: com.sun.star.configuration
from __future__ import annotations
from abc import abstractmethod
from ..uno.x_interface import XInterface as XInterface_8f010a43

class XTemplateInstance(XInterface_8f010a43):
    """
    is implemented by objects that are instances of a named template to provide information about the template.
    
    Template names are similar to service names, but apply to structure and content, rather than to type.
    
    Often a template description can be retrieved from a repository and then be interpreted by a factory object. Templates provide a means to build new kinds of objects dynamically.

    See Also:
        `API XTemplateInstance <https://api.libreoffice.org/docs/idl/ref/interfacecom_1_1sun_1_1star_1_1configuration_1_1XTemplateInstance.html>`_
    """
    __ooo_ns__: str = 'com.sun.star.configuration'
    __ooo_full_ns__: str = 'com.sun.star.configuration.XTemplateInstance'
    __ooo_type_name__: str = 'interface'
    __pyunointerface__: str = 'com.sun.star.configuration.XTemplateInstance'

    @abstractmethod
    def getTemplateName(self) -> str:
        """
        retrieves the name of the template
        """
        ...

__all__ = ['XTemplateInstance']





# coding: utf-8
#
# Copyright 2023 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Interface Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.4
# Namespace: com.sun.star.ui
from __future__ import annotations
import typing
from abc import abstractmethod
from ..lang.x_component import XComponent as XComponent_98dc0ab5
from ..lang.x_initialization import XInitialization as XInitialization_d46c0cca
from .xui_configuration import XUIConfiguration as XUIConfiguration_c4eb0c34
from .xui_configuration_persistence import XUIConfigurationPersistence as XUIConfigurationPersistence_661010b9
if typing.TYPE_CHECKING:
    from ..graphic.x_graphic import XGraphic as XGraphic_a4da0afc

class XImageManager(XComponent_98dc0ab5, XInitialization_d46c0cca, XUIConfiguration_c4eb0c34, XUIConfigurationPersistence_661010b9):
    """
    specifies access functions to an images manager interface to add, replace and remove images associations to command URLs.
    
    An image manager controls a number of image sets which are specified by an ImageType.

    See Also:
        `API XImageManager <https://api.libreoffice.org/docs/idl/ref/interfacecom_1_1sun_1_1star_1_1ui_1_1XImageManager.html>`_
    """
    __ooo_ns__: str = 'com.sun.star.ui'
    __ooo_full_ns__: str = 'com.sun.star.ui.XImageManager'
    __ooo_type_name__: str = 'interface'
    __pyunointerface__: str = 'com.sun.star.ui.XImageManager'

    @abstractmethod
    def getAllImageNames(self, nImageType: int) -> typing.Tuple[str, ...]:
        """
        retrieves the list of command URLs which have images associated.
        """
        ...
    @abstractmethod
    def getImages(self, nImageType: int, aCommandURLSequence: typing.Tuple[str, ...]) -> typing.Tuple[XGraphic_a4da0afc, ...]:
        """
        retrieves the associated images of command URLs.

        Raises:
            com.sun.star.lang.IllegalArgumentException: ``IllegalArgumentException``
        """
        ...
    @abstractmethod
    def hasImage(self, nImageType: int, CommandURL: str) -> bool:
        """
        determines if a command URL has an associated image.

        Raises:
            com.sun.star.lang.IllegalArgumentException: ``IllegalArgumentException``
        """
        ...
    @abstractmethod
    def insertImages(self, nImageType: int, aCommandURLSequence: typing.Tuple[str, ...], aGraphicSequence: typing.Tuple[XGraphic_a4da0afc, ...]) -> None:
        """
        inserts new image/command associations to an image manager.
        
        If an association is already present it is replaced. If aCommandURLSequence contains an invalid command URL a com.sun.star.lang.IllegalArgumentException is thrown. If the configuration manager is read-only a com.sun.star.lang.IllegalAccessException is thrown.

        Raises:
            com.sun.star.container.ElementExistException: ``ElementExistException``
            com.sun.star.lang.IllegalArgumentException: ``IllegalArgumentException``
            com.sun.star.lang.IllegalAccessException: ``IllegalAccessException``
        """
        ...
    @abstractmethod
    def removeImages(self, nImageType: int, CommandURLs: typing.Tuple[str, ...]) -> None:
        """
        removes associated images to a command URL.
        
        If the aCommandURLSequence contains an invalid command URL a com.sun.star.lang.IllegalArgumentException is thrown. If the image manager is associated with a read-only configuration manager a com.sun.star.lang.IllegalAccessException is thrown.

        Raises:
            com.sun.star.lang.IllegalArgumentException: ``IllegalArgumentException``
            com.sun.star.lang.IllegalAccessException: ``IllegalAccessException``
        """
        ...
    @abstractmethod
    def replaceImages(self, nImageType: int, aCommandURLSequence: typing.Tuple[str, ...], aGraphicsSequence: typing.Tuple[XGraphic_a4da0afc, ...]) -> None:
        """
        replaces the associated images of command URLs.
        
        If a command URL cannot be found the replace call will be omitted. If aCommandURLSequence contains an invalid command URL a com.sun.star.lang.IllegalArgumentException is thrown. If the image manager is associated with a read-only configuration manager a com.sun.star.lang.IllegalAccessException is thrown.

        Raises:
            com.sun.star.lang.IllegalArgumentException: ``IllegalArgumentException``
            com.sun.star.lang.IllegalAccessException: ``IllegalAccessException``
        """
        ...
    @abstractmethod
    def reset(self) -> None:
        """
        resets the image manager to default data.
        
        This means that all user images of the instance will be removed.

        Raises:
            com.sun.star.lang.IllegalArgumentException: ``IllegalArgumentException``
            com.sun.star.lang.IllegalAccessException: ``IllegalAccessException``
        """
        ...

__all__ = ['XImageManager']





# coding: utf-8
#
# Copyright 2023 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Struct Class
# this is a auto generated file generated by Cheetah
# Namespace: com.sun.star.embed
# Libre Office Version: 7.4
from ooo.oenv.env_const import UNO_NONE
import typing
from ..datatransfer.data_flavor import DataFlavor as DataFlavor_ffd30deb


class VisualRepresentation(object):
    """
    Struct Class

    can contain a graphical representation in an arbitrary format.

    See Also:
        `API VisualRepresentation <https://api.libreoffice.org/docs/idl/ref/structcom_1_1sun_1_1star_1_1embed_1_1VisualRepresentation.html>`_
    """
    __ooo_ns__: str = 'com.sun.star.embed'
    __ooo_full_ns__: str = 'com.sun.star.embed.VisualRepresentation'
    __ooo_type_name__: str = 'struct'
    typeName: str = 'com.sun.star.embed.VisualRepresentation'
    """Literal Constant ``com.sun.star.embed.VisualRepresentation``"""

    def __init__(self, Flavor: typing.Optional[DataFlavor_ffd30deb] = UNO_NONE, Data: typing.Optional[object] = None) -> None:
        """
        Constructor

        Arguments:
            Flavor (DataFlavor, optional): Flavor value.
            Data (object, optional): Data value.
        """
        super().__init__()

        if isinstance(Flavor, VisualRepresentation):
            oth: VisualRepresentation = Flavor
            self.Flavor = oth.Flavor
            self.Data = oth.Data
            return

        kargs = {
            "Flavor": Flavor,
            "Data": Data,
        }
        if kargs["Flavor"] is UNO_NONE:
            kargs["Flavor"] = None
        self._init(**kargs)

    def _init(self, **kwargs) -> None:
        self._flavor = kwargs["Flavor"]
        self._data = kwargs["Data"]


    @property
    def Flavor(self) -> DataFlavor_ffd30deb:
        """
        The format of the visual representation.
        """
        return self._flavor

    @Flavor.setter
    def Flavor(self, value: DataFlavor_ffd30deb) -> None:
        self._flavor = value

    @property
    def Data(self) -> object:
        """
        The data in the format specified by Flavor.
        """
        return self._data

    @Data.setter
    def Data(self, value: object) -> None:
        self._data = value


__all__ = ['VisualRepresentation']



# coding: utf-8
#
# Copyright 2023 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Struct Class
# this is a auto generated file generated by Cheetah
# Namespace: com.sun.star.xml.crypto.sax
# Libre Office Version: 7.4
from ooo.oenv.env_const import UNO_NONE
import typing
from ...sax.x_attribute_list import XAttributeList as XAttributeList_eec70d7b


class ElementStackItem(object):
    """
    Struct Class

    A struct to keep a startElement/endElement SAX event.

    See Also:
        `API ElementStackItem <https://api.libreoffice.org/docs/idl/ref/structcom_1_1sun_1_1star_1_1xml_1_1crypto_1_1sax_1_1ElementStackItem.html>`_
    """
    __ooo_ns__: str = 'com.sun.star.xml.crypto.sax'
    __ooo_full_ns__: str = 'com.sun.star.xml.crypto.sax.ElementStackItem'
    __ooo_type_name__: str = 'struct'
    typeName: str = 'com.sun.star.xml.crypto.sax.ElementStackItem'
    """Literal Constant ``com.sun.star.xml.crypto.sax.ElementStackItem``"""

    def __init__(self, isStartElementEvent: typing.Optional[bool] = False, elementName: typing.Optional[str] = '', xAttributes: typing.Optional[XAttributeList_eec70d7b] = None) -> None:
        """
        Constructor

        Arguments:
            isStartElementEvent (bool, optional): isStartElementEvent value.
            elementName (str, optional): elementName value.
            xAttributes (XAttributeList, optional): xAttributes value.
        """
        super().__init__()

        if isinstance(isStartElementEvent, ElementStackItem):
            oth: ElementStackItem = isStartElementEvent
            self.isStartElementEvent = oth.isStartElementEvent
            self.elementName = oth.elementName
            self.xAttributes = oth.xAttributes
            return

        kargs = {
            "isStartElementEvent": isStartElementEvent,
            "elementName": elementName,
            "xAttributes": xAttributes,
        }
        self._init(**kargs)

    def _init(self, **kwargs) -> None:
        self._is_start_element_event = kwargs["isStartElementEvent"]
        self._element_name = kwargs["elementName"]
        self._x_attributes = kwargs["xAttributes"]


    @property
    def isStartElementEvent(self) -> bool:
        """
        whether it is a startElement event
        """
        return self._is_start_element_event

    @isStartElementEvent.setter
    def isStartElementEvent(self, value: bool) -> None:
        self._is_start_element_event = value

    @property
    def elementName(self) -> str:
        """
        the name of the element
        """
        return self._element_name

    @elementName.setter
    def elementName(self, value: str) -> None:
        self._element_name = value

    @property
    def xAttributes(self) -> XAttributeList_eec70d7b:
        """
        attribute list for a startElement event
        """
        return self._x_attributes

    @xAttributes.setter
    def xAttributes(self, value: XAttributeList_eec70d7b) -> None:
        self._x_attributes = value


__all__ = ['ElementStackItem']



# coding: utf-8
#
# Copyright 2023 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Struct Class
# this is a auto generated file generated by Cheetah
# Namespace: com.sun.star.table
# Libre Office Version: 7.4
from ooo.oenv.env_const import UNO_NONE
import typing
from .border_line import BorderLine as BorderLine_a3f80af6


class TableBorder(object):
    """
    Struct Class

    contains the style settings of the border lines of all cells in a cell range.
    
    In a queried structure, the flags in TableBorder.Is...LineValid indicate that not all lines of the boxes have the same values.
    
    In a structure which is used for setting, these flags determine if the corresponding line should be set or if the old value should be kept.

    See Also:
        `API TableBorder <https://api.libreoffice.org/docs/idl/ref/structcom_1_1sun_1_1star_1_1table_1_1TableBorder.html>`_
    """
    __ooo_ns__: str = 'com.sun.star.table'
    __ooo_full_ns__: str = 'com.sun.star.table.TableBorder'
    __ooo_type_name__: str = 'struct'
    typeName: str = 'com.sun.star.table.TableBorder'
    """Literal Constant ``com.sun.star.table.TableBorder``"""

    def __init__(self, TopLine: typing.Optional[BorderLine_a3f80af6] = UNO_NONE, IsTopLineValid: typing.Optional[bool] = False, BottomLine: typing.Optional[BorderLine_a3f80af6] = UNO_NONE, IsBottomLineValid: typing.Optional[bool] = False, LeftLine: typing.Optional[BorderLine_a3f80af6] = UNO_NONE, IsLeftLineValid: typing.Optional[bool] = False, RightLine: typing.Optional[BorderLine_a3f80af6] = UNO_NONE, IsRightLineValid: typing.Optional[bool] = False, HorizontalLine: typing.Optional[BorderLine_a3f80af6] = UNO_NONE, IsHorizontalLineValid: typing.Optional[bool] = False, VerticalLine: typing.Optional[BorderLine_a3f80af6] = UNO_NONE, IsVerticalLineValid: typing.Optional[bool] = False, Distance: typing.Optional[int] = 0, IsDistanceValid: typing.Optional[bool] = False) -> None:
        """
        Constructor

        Arguments:
            TopLine (BorderLine, optional): TopLine value.
            IsTopLineValid (bool, optional): IsTopLineValid value.
            BottomLine (BorderLine, optional): BottomLine value.
            IsBottomLineValid (bool, optional): IsBottomLineValid value.
            LeftLine (BorderLine, optional): LeftLine value.
            IsLeftLineValid (bool, optional): IsLeftLineValid value.
            RightLine (BorderLine, optional): RightLine value.
            IsRightLineValid (bool, optional): IsRightLineValid value.
            HorizontalLine (BorderLine, optional): HorizontalLine value.
            IsHorizontalLineValid (bool, optional): IsHorizontalLineValid value.
            VerticalLine (BorderLine, optional): VerticalLine value.
            IsVerticalLineValid (bool, optional): IsVerticalLineValid value.
            Distance (int, optional): Distance value.
            IsDistanceValid (bool, optional): IsDistanceValid value.
        """
        super().__init__()

        if isinstance(TopLine, TableBorder):
            oth: TableBorder = TopLine
            self.TopLine = oth.TopLine
            self.IsTopLineValid = oth.IsTopLineValid
            self.BottomLine = oth.BottomLine
            self.IsBottomLineValid = oth.IsBottomLineValid
            self.LeftLine = oth.LeftLine
            self.IsLeftLineValid = oth.IsLeftLineValid
            self.RightLine = oth.RightLine
            self.IsRightLineValid = oth.IsRightLineValid
            self.HorizontalLine = oth.HorizontalLine
            self.IsHorizontalLineValid = oth.IsHorizontalLineValid
            self.VerticalLine = oth.VerticalLine
            self.IsVerticalLineValid = oth.IsVerticalLineValid
            self.Distance = oth.Distance
            self.IsDistanceValid = oth.IsDistanceValid
            return

        kargs = {
            "TopLine": TopLine,
            "IsTopLineValid": IsTopLineValid,
            "BottomLine": BottomLine,
            "IsBottomLineValid": IsBottomLineValid,
            "LeftLine": LeftLine,
            "IsLeftLineValid": IsLeftLineValid,
            "RightLine": RightLine,
            "IsRightLineValid": IsRightLineValid,
            "HorizontalLine": HorizontalLine,
            "IsHorizontalLineValid": IsHorizontalLineValid,
            "VerticalLine": VerticalLine,
            "IsVerticalLineValid": IsVerticalLineValid,
            "Distance": Distance,
            "IsDistanceValid": IsDistanceValid,
        }
        if kargs["TopLine"] is UNO_NONE:
            kargs["TopLine"] = None
        if kargs["BottomLine"] is UNO_NONE:
            kargs["BottomLine"] = None
        if kargs["LeftLine"] is UNO_NONE:
            kargs["LeftLine"] = None
        if kargs["RightLine"] is UNO_NONE:
            kargs["RightLine"] = None
        if kargs["HorizontalLine"] is UNO_NONE:
            kargs["HorizontalLine"] = None
        if kargs["VerticalLine"] is UNO_NONE:
            kargs["VerticalLine"] = None
        self._init(**kargs)

    def _init(self, **kwargs) -> None:
        self._top_line = kwargs["TopLine"]
        self._is_top_line_valid = kwargs["IsTopLineValid"]
        self._bottom_line = kwargs["BottomLine"]
        self._is_bottom_line_valid = kwargs["IsBottomLineValid"]
        self._left_line = kwargs["LeftLine"]
        self._is_left_line_valid = kwargs["IsLeftLineValid"]
        self._right_line = kwargs["RightLine"]
        self._is_right_line_valid = kwargs["IsRightLineValid"]
        self._horizontal_line = kwargs["HorizontalLine"]
        self._is_horizontal_line_valid = kwargs["IsHorizontalLineValid"]
        self._vertical_line = kwargs["VerticalLine"]
        self._is_vertical_line_valid = kwargs["IsVerticalLineValid"]
        self._distance = kwargs["Distance"]
        self._is_distance_valid = kwargs["IsDistanceValid"]


    @property
    def TopLine(self) -> BorderLine_a3f80af6:
        """
        determines the line style at the top edge.
        """
        return self._top_line

    @TopLine.setter
    def TopLine(self, value: BorderLine_a3f80af6) -> None:
        self._top_line = value

    @property
    def IsTopLineValid(self) -> bool:
        """
        specifies whether the value of TableBorder.TopLine is used.
        """
        return self._is_top_line_valid

    @IsTopLineValid.setter
    def IsTopLineValid(self, value: bool) -> None:
        self._is_top_line_valid = value

    @property
    def BottomLine(self) -> BorderLine_a3f80af6:
        """
        determines the line style at the bottom edge.
        """
        return self._bottom_line

    @BottomLine.setter
    def BottomLine(self, value: BorderLine_a3f80af6) -> None:
        self._bottom_line = value

    @property
    def IsBottomLineValid(self) -> bool:
        """
        specifies whether the value of TableBorder.BottomLine is used.
        """
        return self._is_bottom_line_valid

    @IsBottomLineValid.setter
    def IsBottomLineValid(self, value: bool) -> None:
        self._is_bottom_line_valid = value

    @property
    def LeftLine(self) -> BorderLine_a3f80af6:
        """
        determines the line style at the left edge.
        """
        return self._left_line

    @LeftLine.setter
    def LeftLine(self, value: BorderLine_a3f80af6) -> None:
        self._left_line = value

    @property
    def IsLeftLineValid(self) -> bool:
        """
        specifies whether the value of TableBorder.LeftLine is used.
        """
        return self._is_left_line_valid

    @IsLeftLineValid.setter
    def IsLeftLineValid(self, value: bool) -> None:
        self._is_left_line_valid = value

    @property
    def RightLine(self) -> BorderLine_a3f80af6:
        """
        determines the line style at the right edge.
        """
        return self._right_line

    @RightLine.setter
    def RightLine(self, value: BorderLine_a3f80af6) -> None:
        self._right_line = value

    @property
    def IsRightLineValid(self) -> bool:
        """
        specifies whether the value of TableBorder.RightLine is used.
        """
        return self._is_right_line_valid

    @IsRightLineValid.setter
    def IsRightLineValid(self, value: bool) -> None:
        self._is_right_line_valid = value

    @property
    def HorizontalLine(self) -> BorderLine_a3f80af6:
        """
        determines the line style of horizontal lines for the inner part of a cell range.
        """
        return self._horizontal_line

    @HorizontalLine.setter
    def HorizontalLine(self, value: BorderLine_a3f80af6) -> None:
        self._horizontal_line = value

    @property
    def IsHorizontalLineValid(self) -> bool:
        """
        specifies whether the value of TableBorder.HorizontalLine is used.
        """
        return self._is_horizontal_line_valid

    @IsHorizontalLineValid.setter
    def IsHorizontalLineValid(self, value: bool) -> None:
        self._is_horizontal_line_valid = value

    @property
    def VerticalLine(self) -> BorderLine_a3f80af6:
        """
        determines the line style of vertical lines for the inner part of a cell range.
        """
        return self._vertical_line

    @VerticalLine.setter
    def VerticalLine(self, value: BorderLine_a3f80af6) -> None:
        self._vertical_line = value

    @property
    def IsVerticalLineValid(self) -> bool:
        """
        specifies whether the value of TableBorder.VerticalLine is used.
        """
        return self._is_vertical_line_valid

    @IsVerticalLineValid.setter
    def IsVerticalLineValid(self, value: bool) -> None:
        self._is_vertical_line_valid = value

    @property
    def Distance(self) -> int:
        """
        contains the distance between the lines and other contents.
        """
        return self._distance

    @Distance.setter
    def Distance(self, value: int) -> None:
        self._distance = value

    @property
    def IsDistanceValid(self) -> bool:
        """
        specifies whether the value of TableBorder.Distance is used.
        """
        return self._is_distance_valid

    @IsDistanceValid.setter
    def IsDistanceValid(self, value: bool) -> None:
        self._is_distance_valid = value


__all__ = ['TableBorder']



# coding: utf-8
#
# Copyright 2023 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Service Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.4
# Namespace: com.sun.star.drawing
from __future__ import annotations
import typing
from abc import abstractproperty
from ..beans.x_property_set import XPropertySet as XPropertySet_bc180bfa
from ..container.x_named import XNamed as XNamed_a6520b08
from .x_shape_binder import XShapeBinder as XShapeBinder_d4f70c91
from .x_shape_combiner import XShapeCombiner as XShapeCombiner_ef7b0d6c
from .x_shape_grouper import XShapeGrouper as XShapeGrouper_e2a30d21
from .x_shapes import XShapes as XShapes_9a800ab0
if typing.TYPE_CHECKING:
    from ..container.x_index_access import XIndexAccess as XIndexAccess_f0910d6d
    from ..container.x_name_container import XNameContainer as XNameContainer_cb90e47
    from com.sun.star.view.PaperOrientation import PaperOrientationProto  # type: ignore

class GenericDrawPage(XPropertySet_bc180bfa, XNamed_a6520b08, XShapeBinder_d4f70c91, XShapeCombiner_ef7b0d6c, XShapeGrouper_e2a30d21, XShapes_9a800ab0):
    """
    Service Class

    This abstract service is implemented by every page of a DrawingDocument.
    
    Example to create and insert a couple of LineShapes:
    
    **since**
    
        LibreOffice 7.2

    See Also:
        `API GenericDrawPage <https://api.libreoffice.org/docs/idl/ref/servicecom_1_1sun_1_1star_1_1drawing_1_1GenericDrawPage.html>`_
    """
    __ooo_ns__: str = 'com.sun.star.drawing'
    __ooo_full_ns__: str = 'com.sun.star.drawing.GenericDrawPage'
    __ooo_type_name__: str = 'service'

    @abstractproperty
    def BackgroundFullSize(self) -> bool:
        """
        does the background cover the full page or only inside the margins?
        
        **since**
        
            LibreOffice 7.2
        """
        ...

    @abstractproperty
    def BorderBottom(self) -> int:
        """
        This is the border at the bottom.
        """
        ...

    @abstractproperty
    def BorderLeft(self) -> int:
        """
        This is the border at the left.
        """
        ...

    @abstractproperty
    def BorderRight(self) -> int:
        """
        This is the border at the right.
        """
        ...

    @abstractproperty
    def BorderTop(self) -> int:
        """
        This is the border at the top.
        """
        ...

    @abstractproperty
    def Height(self) -> int:
        """
        This is the height.
        """
        ...

    @abstractproperty
    def IsBackgroundDark(self) -> bool:
        """
        this property is true if the averaged background filling colors luminance is below an application specified threshold value.
        
        This can be used to determine the actual value of an auto color.
        """
        ...

    @abstractproperty
    def NavigationOrder(self) -> XIndexAccess_f0910d6d:
        """
        this index access defines a navigation order for the top level shapes inside this page.
        
        By default this is equal to the index access of the slide itself, making the z-order the default navigation order for top level shapes.
        """
        ...

    @abstractproperty
    def Number(self) -> int:
        """
        This is the number of this page, starting with 1.
        """
        ...

    @abstractproperty
    def Orientation(self) -> PaperOrientationProto:
        """
        This is the orientation of this page.
        """
        ...

    @abstractproperty
    def UserDefinedAttributes(self) -> XNameContainer_cb90e47:
        """
        this property stores xml attributes.
        
        They will be saved to and restored from automatic styles inside xml files.
        """
        ...

    @abstractproperty
    def Width(self) -> int:
        """
        This is the width.
        """
        ...


__all__ = ['GenericDrawPage']


# coding: utf-8
#
# Copyright 2023 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Enum Class
# this is a auto generated file generated by Cheetah
# Namespace: com.sun.star.drawing
# Libre Office Version: 7.4
from __future__ import annotations
from enum import Enum


class TextureKind(Enum):
    """
    Enum Class


    See Also:
        `API TextureKind <https://api.libreoffice.org/docs/idl/ref/namespacecom_1_1sun_1_1star_1_1drawing.html#a36a384629c2a5cfb1a9d019d30923c2b>`_
    """
    __ooo_ns__: str = "com.sun.star.drawing"
    __ooo_full_ns__: str = "com.sun.star.drawing.TextureKind"
    __ooo_type_name__: str = "enum"

    @property
    def typeName(self) -> str:
        return "com.sun.star.drawing.TextureKind"

    COLOR = "COLOR"
    """
    With this mode the lighting is ignored and only the texture color information is used.
    
    With this mode, the lighting is ignored and only the texture color information is used.
    """
    LUMINANCE = "LUMINANCE"
    """
    With TextureKind LUMINANCE, the texture and the lighting information is mixed to produce the image, so a lit, textured object is achieved.
    """

__all__ = ["TextureKind"]




# coding: utf-8
#
# Copyright 2023 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Service Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.4
# Namespace: com.sun.star.form.binding
from __future__ import annotations
from abc import abstractproperty
from .bindable_data_aware_control_model import BindableDataAwareControlModel as BindableDataAwareControlModel_47091512
from ..component.database_check_box import DatabaseCheckBox as DatabaseCheckBox_7a5910d9

class BindableDatabaseCheckBox(BindableDataAwareControlModel_47091512, DatabaseCheckBox_7a5910d9):
    """
    Service Class

    This service specifies a check box which is data-aware and thus can be bound to a database field, and additionally supports binding to arbitrary external values.
    
    The com.sun.star.form.binding.XValueBinding instance which can be associated with a BindableDatabaseCheckBox must support exchanging boolean values. The following mapping between external values and control states apply:
    
    If the value binding associated with a BindableDatabaseCheckBox supports exchanging string values, and the com.sun.star.form.component.CheckBox.RefValue is not empty, then the radio button will exchange its value as string:

    See Also:
        `API BindableDatabaseCheckBox <https://api.libreoffice.org/docs/idl/ref/servicecom_1_1sun_1_1star_1_1form_1_1binding_1_1BindableDatabaseCheckBox.html>`_
    """
    __ooo_ns__: str = 'com.sun.star.form.binding'
    __ooo_full_ns__: str = 'com.sun.star.form.binding.BindableDatabaseCheckBox'
    __ooo_type_name__: str = 'service'

    @abstractproperty
    def SecondaryRefValue(self) -> str:
        """
        specifies a value which is to be associated with the control when it's not checked.
        
        com.sun.star.form.component.CheckBox.RefValue is transferred to possible external value bindings as soon as the check box is checked. With the member SecondaryRefValue, clients of the check box can also associate a value with the not checked state of the control.
        """
        ...


__all__ = ['BindableDatabaseCheckBox']




# coding: utf-8
#
# Copyright 2023 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Service Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.4
# Namespace: com.sun.star.text.textfield
from __future__ import annotations
import typing
from abc import abstractproperty
from ..text_field import TextField as TextField_90260a56
if typing.TYPE_CHECKING:
    from ...util.date_time import DateTime as DateTime_84de09d3

class DateTime(TextField_90260a56):
    """
    Service Class

    specifies service of a date or time text field.
    
    **since**
    
        OOo 1.1.2

    See Also:
        `API DateTime <https://api.libreoffice.org/docs/idl/ref/servicecom_1_1sun_1_1star_1_1text_1_1textfield_1_1DateTime.html>`_
    """
    __ooo_ns__: str = 'com.sun.star.text.textfield'
    __ooo_full_ns__: str = 'com.sun.star.text.textfield.DateTime'
    __ooo_type_name__: str = 'service'

    @abstractproperty
    def Adjust(self) -> int:
        """
        contains an offset to the date or time value in minutes.
        """
        ...

    @abstractproperty
    def DateTimeFormat(self) -> int:
        """
        this is the display format for this field.
        
        Depending on IsDate, this is either a com.sun.star.text.DateDisplayFormat or com.sun.star.text.TimeDisplayFormat.
        
        This property is deprecated and is here only for components that do not support a com.sun.star.util.NumberFormatter.
        """
        ...

    @abstractproperty
    def DateTimeValue(self) -> DateTime_84de09d3:
        """
        the is the content of this field.
        """
        ...

    @abstractproperty
    def IsDate(self) -> bool:
        """
        If this flag is set to TRUE this field represents a date with an optional time.
        
        If it is set to FALSE only the time is used here.
        """
        ...

    @abstractproperty
    def IsFixed(self) -> bool:
        """
        If this flag is set to FALSE the date or time is always displayed as the current date or time.
        
        **since**
        
            OOo 1.1.2
        """
        ...

    @abstractproperty
    def IsFixedLanguage(self) -> bool:
        """
        determines whether changes in language attributes at the position the text field is located also change the number format as appropriate for this language.
        """
        ...

    @abstractproperty
    def NumberFormat(self) -> int:
        """
        this is the number format for this field
        """
        ...


__all__ = ['DateTime']




# coding: utf-8
#
# Copyright 2023 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Interface Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.4
# Namespace: com.sun.star.lang
from __future__ import annotations
import typing
import uno
from abc import abstractmethod
from ..uno.x_interface import XInterface as XInterface_8f010a43

class XTypeProvider(XInterface_8f010a43):
    """
    interface to get information about the types (usually interface types) supported by an object.

    See Also:
        `API XTypeProvider <https://api.libreoffice.org/docs/idl/ref/interfacecom_1_1sun_1_1star_1_1lang_1_1XTypeProvider.html>`_
    """
    __ooo_ns__: str = 'com.sun.star.lang'
    __ooo_full_ns__: str = 'com.sun.star.lang.XTypeProvider'
    __ooo_type_name__: str = 'interface'
    __pyunointerface__: str = 'com.sun.star.lang.XTypeProvider'

    @abstractmethod
    def getImplementationId(self) -> uno.ByteSequence:
        """
        Obsolete unique identifier.
        
        Originally returned a sequence of bytes which, when non-empty, was used as an ID to distinguish unambiguously between two sets of types, for example to realise hashing functionality when the object is introspected. Two objects that returned the same non-empty ID had to return the same set of types in getTypes(). (If a unique ID could not be provided, this method was always allowed to return an empty sequence, though).
        """
        ...
    @abstractmethod
    def getTypes(self) -> typing.Tuple[object, ...]:
        """
        returns a sequence of all types (usually interface types) provided by the object.
        """
        ...

__all__ = ['XTypeProvider']





# coding: utf-8
#
# Copyright 2023 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Service Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.4
# Namespace: com.sun.star.sdb.application
from __future__ import annotations
import typing
from abc import abstractmethod
from .x_copy_table_wizard import XCopyTableWizard as XCopyTableWizard_89b7114f
if typing.TYPE_CHECKING:
    from ...beans.x_property_set import XPropertySet as XPropertySet_bc180bfa
    from ...task.x_interaction_handler import XInteractionHandler as XInteractionHandler_bf80e51

class CopyTableWizard(XCopyTableWizard_89b7114f):
    """
    Service Class

    describes a wizard which can be used to copy table like data from one database to another.
    
    **since**
    
        OOo 2.4

    See Also:
        `API CopyTableWizard <https://api.libreoffice.org/docs/idl/ref/servicecom_1_1sun_1_1star_1_1sdb_1_1application_1_1CopyTableWizard.html>`_
    """
    __ooo_ns__: str = 'com.sun.star.sdb.application'
    __ooo_full_ns__: str = 'com.sun.star.sdb.application.CopyTableWizard'
    __ooo_type_name__: str = 'service'

    @abstractmethod
    def create(self, Source: XPropertySet_bc180bfa, Destination: XPropertySet_bc180bfa) -> None:
        """
        creates an executable wizard dialog, which is to guide the user through copying a table from one database to another.
        
        At creation time, an attempt will be made to obtain the connections described by Source resp. Dest. Failing to do so will result in an exception.
        
        If the connection has been newly created by the wizard (e.g. because the data access descriptor specified a DataSource instead of an ActiveConnection), then this connection will be disposed upon disposal of the wizard.
        
        The following members of the DataAccessDescriptor are supported, and evaluated in the given order:
        
        The first 5 items are used to obtain the connection, the last two to determine which of the connection's objects is to be copied. Note that Command and CommandType are required.
        
        Additionally to the obvious restrictions (such as that creating a view is not possible if the copy source and the copy destination denote different databases), the following restrictions apply to the settings, and possible combinations:
        
        Violating any of the above restrictions will result in an error at creation time.
        
        Only DataSourceName, DatabaseLocation, ActiveConnection are supported, effectively describing the target connection to copy the data to. They're evaluated in the order mentioned here, so if multiple of the are present, only the first one is evaluated.
        
        Also, at the moment the connection which is implied by either of the settings above must support the com.sun.star.sdb.Connection service. In particular, it is not sufficient to pass an SDBC-level connection.
        
        Note that creating a view (see CopyTableOperation.CreateAsView) is not supported if the target connection is an SDBC-level connection only.

        Raises:
            : ````
            : ````
            com.sun.star.lang.WrappedTargetException: ``WrappedTargetException``
        """
        ...
    @abstractmethod
    def createWithInteractionHandler(self, Source: XPropertySet_bc180bfa, Destination: XPropertySet_bc180bfa, InteractionHandler: XInteractionHandler_bf80e51) -> None:
        """
        creates an executable wizard dialog, which is to guide the user through copying a table from one database to another.
        
        The only difference to the create() constructor is that createWithInteractionHandler takes an additional argument, which can be used to intercept interactions (such as error messages) during the wizard run.
        
        When specifying this parameter, you should use an implementation supporting the com.sun.star.sdb.InteractionHandler, since the general-purpose com.sun.star.task.InteractionHandler cannot handle all requests described above.

        Raises:
            : ````
            : ````
            com.sun.star.lang.WrappedTargetException: ``WrappedTargetException``
        """
        ...

__all__ = ['CopyTableWizard']




# coding: utf-8
#
# Copyright 2023 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Struct Class
# this is a auto generated file generated by Cheetah
# Namespace: com.sun.star.sheet.opencl
# Libre Office Version: 7.4
from ooo.oenv.env_const import UNO_NONE
import typing


class OpenCLDevice(object):
    """
    Struct Class


    See Also:
        `API OpenCLDevice <https://api.libreoffice.org/docs/idl/ref/structcom_1_1sun_1_1star_1_1sheet_1_1opencl_1_1OpenCLDevice.html>`_
    """
    __ooo_ns__: str = 'com.sun.star.sheet.opencl'
    __ooo_full_ns__: str = 'com.sun.star.sheet.opencl.OpenCLDevice'
    __ooo_type_name__: str = 'struct'
    typeName: str = 'com.sun.star.sheet.opencl.OpenCLDevice'
    """Literal Constant ``com.sun.star.sheet.opencl.OpenCLDevice``"""

    def __init__(self, Name: typing.Optional[str] = '', Vendor: typing.Optional[str] = '', Driver: typing.Optional[str] = '') -> None:
        """
        Constructor

        Arguments:
            Name (str, optional): Name value.
            Vendor (str, optional): Vendor value.
            Driver (str, optional): Driver value.
        """
        super().__init__()

        if isinstance(Name, OpenCLDevice):
            oth: OpenCLDevice = Name
            self.Name = oth.Name
            self.Vendor = oth.Vendor
            self.Driver = oth.Driver
            return

        kargs = {
            "Name": Name,
            "Vendor": Vendor,
            "Driver": Driver,
        }
        self._init(**kargs)

    def _init(self, **kwargs) -> None:
        self._name = kwargs["Name"]
        self._vendor = kwargs["Vendor"]
        self._driver = kwargs["Driver"]


    @property
    def Name(self) -> str:
        """
        The name of the device as returned by OpenCL.
        """
        return self._name

    @Name.setter
    def Name(self, value: str) -> None:
        self._name = value

    @property
    def Vendor(self) -> str:
        """
        The vendor of the device as returned by OpenCL.
        """
        return self._vendor

    @Vendor.setter
    def Vendor(self, value: str) -> None:
        self._vendor = value

    @property
    def Driver(self) -> str:
        """
        The driver version as returned by OpenCL.
        """
        return self._driver

    @Driver.setter
    def Driver(self, value: str) -> None:
        self._driver = value


__all__ = ['OpenCLDevice']



# coding: utf-8
#
# Copyright 2023 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Service Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.4
# Namespace: com.sun.star.embed
from __future__ import annotations
import typing
from abc import abstractmethod
from ..lang.x_component import XComponent as XComponent_98dc0ab5
if typing.TYPE_CHECKING:
    from ..frame.x_frame import XFrame as XFrame_7a570956

class DocumentCloser(XComponent_98dc0ab5):
    """
    Service Class

    The main task of this service is to close an office document frame embedded in an application running in another process correctly.
    
    The usual usage of this service is to create it, initialize with document frame, and to dispose the service. While disposing the service will do all the required actions to let the frame be closed using com.sun.star.util.XCloseable.close( true ). Thus in case there is a code that prevents closing of the frame the code automatically becomes the owner of the frame.
    
    In addition the code will disconnect the VCL window the frame is based on from the container system window.

    See Also:
        `API DocumentCloser <https://api.libreoffice.org/docs/idl/ref/servicecom_1_1sun_1_1star_1_1embed_1_1DocumentCloser.html>`_
    """
    __ooo_ns__: str = 'com.sun.star.embed'
    __ooo_full_ns__: str = 'com.sun.star.embed.DocumentCloser'
    __ooo_type_name__: str = 'service'

    @abstractmethod
    def DocumentCloserCtor1(self, xFrame: XFrame_7a570956) -> None:
        """
        is used to initialize the object on it's creation.

        Raises:
            com.sun.star.lang.IllegalArgumentException: ``IllegalArgumentException``
            com.sun.star.frame.DoubleInitializationException: ``DoubleInitializationException``
            com.sun.star.uno.Exception: ``Exception``
        """
        ...

__all__ = ['DocumentCloser']




# coding: utf-8
#
# Copyright 2023 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Service Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.4
# Namespace: com.sun.star.reflection
from __future__ import annotations
from ..container.x_hierarchical_name_access import XHierarchicalNameAccess as XHierarchicalNameAccess_9e2611b5
from ..lang.x_component import XComponent as XComponent_98dc0ab5
from .x_type_description_enumeration_access import XTypeDescriptionEnumerationAccess as XTypeDescriptionEnumerationAccess_8417168a

class TypeDescriptionProvider(XHierarchicalNameAccess_9e2611b5, XComponent_98dc0ab5, XTypeDescriptionEnumerationAccess_8417168a):
    """
    Service Class

    This service provides type descriptions, i.e.
    
    concrete service implementations read from source like the persistent registry database format.
    
    This old-style service definition mostly serves documentation purposes. It is not intended that an implementation of this service can be obtained at the global service manager using this service identifier.
    
    **since**
    
        OOo 1.1.2

    See Also:
        `API TypeDescriptionProvider <https://api.libreoffice.org/docs/idl/ref/servicecom_1_1sun_1_1star_1_1reflection_1_1TypeDescriptionProvider.html>`_
    """
    __ooo_ns__: str = 'com.sun.star.reflection'
    __ooo_full_ns__: str = 'com.sun.star.reflection.TypeDescriptionProvider'
    __ooo_type_name__: str = 'service'


__all__ = ['TypeDescriptionProvider']




# coding: utf-8
#
# Copyright 2023 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Interface Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.4
# Namespace: com.sun.star.sheet
from __future__ import annotations
import typing
from abc import abstractmethod
from ..uno.x_interface import XInterface as XInterface_8f010a43
if typing.TYPE_CHECKING:
    from ..beans.property_value import PropertyValue as PropertyValue_c9610c73
    from .x_range_selection_change_listener import XRangeSelectionChangeListener as XRangeSelectionChangeListener_c0021298
    from .x_range_selection_listener import XRangeSelectionListener as XRangeSelectionListener_57ef1052

class XRangeSelection(XInterface_8f010a43):
    """
    allows to let the user to select a cell range.

    See Also:
        `API XRangeSelection <https://api.libreoffice.org/docs/idl/ref/interfacecom_1_1sun_1_1star_1_1sheet_1_1XRangeSelection.html>`_
    """
    __ooo_ns__: str = 'com.sun.star.sheet'
    __ooo_full_ns__: str = 'com.sun.star.sheet.XRangeSelection'
    __ooo_type_name__: str = 'interface'
    __pyunointerface__: str = 'com.sun.star.sheet.XRangeSelection'

    @abstractmethod
    def abortRangeSelection(self) -> None:
        """
        aborts the range selection.
        """
        ...
    @abstractmethod
    def addRangeSelectionChangeListener(self, aListener: XRangeSelectionChangeListener_c0021298) -> None:
        """
        adds a listener that is notified when the selected range is changed.
        """
        ...
    @abstractmethod
    def addRangeSelectionListener(self, aListener: XRangeSelectionListener_57ef1052) -> None:
        """
        adds a listener that is notified when range selection is completed or aborted.
        """
        ...
    @abstractmethod
    def removeRangeSelectionChangeListener(self, aListener: XRangeSelectionChangeListener_c0021298) -> None:
        """
        removes the specified listener.
        """
        ...
    @abstractmethod
    def removeRangeSelectionListener(self, aListener: XRangeSelectionListener_57ef1052) -> None:
        """
        removes the specified listener.
        """
        ...
    @abstractmethod
    def startRangeSelection(self, aArguments: typing.Tuple[PropertyValue_c9610c73, ...]) -> None:
        """
        starts the range selection.
        """
        ...

__all__ = ['XRangeSelection']





# coding: utf-8
#
# Copyright 2023 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Interface Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.4
# Namespace: com.sun.star.sdb.application
from __future__ import annotations
import typing
from abc import abstractmethod, ABC
if typing.TYPE_CHECKING:
    from ...graphic.x_graphic import XGraphic as XGraphic_a4da0afc
    from .x_database_document_ui import XDatabaseDocumentUI as XDatabaseDocumentUI_be9c124d
    from ...uno.x_interface import XInterface as XInterface_8f010a43

class XTableUIProvider(ABC):
    """
    is used by the database application to obtain non-default user interface information and/or components for database tables.
    
    **since**
    
        OOo 2.2

    See Also:
        `API XTableUIProvider <https://api.libreoffice.org/docs/idl/ref/interfacecom_1_1sun_1_1star_1_1sdb_1_1application_1_1XTableUIProvider.html>`_
    """
    __ooo_ns__: str = 'com.sun.star.sdb.application'
    __ooo_full_ns__: str = 'com.sun.star.sdb.application.XTableUIProvider'
    __ooo_type_name__: str = 'interface'
    __pyunointerface__: str = 'com.sun.star.sdb.application.XTableUIProvider'

    @abstractmethod
    def getTableEditor(self, DocumentUI: XDatabaseDocumentUI_be9c124d, TableName: str) -> XInterface_8f010a43:
        """
        returns a component which can be used to edit the definition of an existing table.

        Raises:
            com.sun.star.lang.IllegalArgumentException: ``IllegalArgumentException``
            com.sun.star.lang.WrappedTargetException: ``WrappedTargetException``
        """
        ...
    @abstractmethod
    def getTableIcon(self, TableName: str, ColorMode: int) -> XGraphic_a4da0afc:
        """
        provides the icon which should be used to represent the table in the database application window.
        
        The icon will usually be requested once per table, and cached. It might be requested again if the application settings change, for instance, if another desktop theme has been activated.
        """
        ...

__all__ = ['XTableUIProvider']





# coding: utf-8
#
# Copyright 2023 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Interface Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.4
# Namespace: com.sun.star.sdbc
from __future__ import annotations
import typing
from abc import abstractmethod
from ..uno.x_interface import XInterface as XInterface_8f010a43
if typing.TYPE_CHECKING:
    from .x_connection import XConnection as XConnection_a36a0b0c
    from .x_result_set import XResultSet as XResultSet_98e30aa7

class XPreparedStatement(XInterface_8f010a43):
    """
    provides the possibility of executing a precompiled SQL statement.
    
    A SQL statement is pre-compiled and stored in a PreparedStatement object. This object can then be used to efficiently execute this statement multiple times.

    See Also:
        `API XPreparedStatement <https://api.libreoffice.org/docs/idl/ref/interfacecom_1_1sun_1_1star_1_1sdbc_1_1XPreparedStatement.html>`_
    """
    __ooo_ns__: str = 'com.sun.star.sdbc'
    __ooo_full_ns__: str = 'com.sun.star.sdbc.XPreparedStatement'
    __ooo_type_name__: str = 'interface'
    __pyunointerface__: str = 'com.sun.star.sdbc.XPreparedStatement'

    @abstractmethod
    def execute(self) -> bool:
        """
        executes any kind of SQL statement.
        
        Some prepared statements return multiple results; the execute method handles these complex statements as well as the simpler form of statements handled by executeQuery and executeUpdate.

        Raises:
            SQLException: ``SQLException``
        """
        ...
    @abstractmethod
    def executeQuery(self) -> XResultSet_98e30aa7:
        """
        executes the SQL query in this PreparedStatement object and returns the result set generated by the query.

        Raises:
            SQLException: ``SQLException``
        """
        ...
    @abstractmethod
    def executeUpdate(self) -> int:
        """
        executes the SQL INSERT, UPDATE or DELETE statement in this com.sun.star.sdbc.PreparedStatement object.
        
        In addition, SQL statements that return nothing, such as SQL DDL statements, can be executed.

        Raises:
            SQLException: ``SQLException``
        """
        ...
    @abstractmethod
    def getConnection(self) -> XConnection_a36a0b0c:
        """
        returns the com.sun.star.sdbc.Connection object that produced this com.sun.star.sdbc.Statement object.

        Raises:
            SQLException: ``SQLException``
        """
        ...

__all__ = ['XPreparedStatement']





# coding: utf-8
#
# Copyright 2023 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Struct Class
# this is a auto generated file generated by Cheetah
# Namespace: com.sun.star.util
# Libre Office Version: 7.4
from ooo.oenv.env_const import UNO_NONE
from ..lang.event_object import EventObject as EventObject_a3d70b03
from ..uno.x_interface import XInterface as XInterface_8f010a43
import typing
from .changes_set import ChangesSet as ChangesSet_99de0aab


class ChangesEvent(EventObject_a3d70b03):
    """
    Struct Class

    This event is fired when a set of changes becomes effective on the source of the event.

    See Also:
        `API ChangesEvent <https://api.libreoffice.org/docs/idl/ref/structcom_1_1sun_1_1star_1_1util_1_1ChangesEvent.html>`_
    """
    __ooo_ns__: str = 'com.sun.star.util'
    __ooo_full_ns__: str = 'com.sun.star.util.ChangesEvent'
    __ooo_type_name__: str = 'struct'
    typeName: str = 'com.sun.star.util.ChangesEvent'
    """Literal Constant ``com.sun.star.util.ChangesEvent``"""

    def __init__(self, Source: typing.Optional[XInterface_8f010a43] = None, Base: typing.Optional[object] = None, Changes: typing.Optional[ChangesSet_99de0aab] = ChangesSet_99de0aab(())) -> None:
        """
        Constructor

        Arguments:
            Source (XInterface, optional): Source value.
            Base (object, optional): Base value.
            Changes (ChangesSet, optional): Changes value.
        """

        if isinstance(Source, ChangesEvent):
            oth: ChangesEvent = Source
            self.Source = oth.Source
            self.Base = oth.Base
            self.Changes = oth.Changes
            return

        kargs = {
            "Source": Source,
            "Base": Base,
            "Changes": Changes,
        }
        self._init(**kargs)

    def _init(self, **kwargs) -> None:
        self._base = kwargs["Base"]
        self._changes = kwargs["Changes"]
        inst_keys = ('Base', 'Changes')
        kargs = kwargs.copy()
        for key in inst_keys:
            del kargs[key]
        super()._init(**kargs)


    @property
    def Base(self) -> object:
        """
        contains the accessor to the common root of the changed elements.
        
        Type and value of the accessor depend on the service.
        """
        return self._base

    @Base.setter
    def Base(self, value: object) -> None:
        self._base = value

    @property
    def Changes(self) -> ChangesSet_99de0aab:
        """
        contains the changes which occurred.
        """
        return self._changes

    @Changes.setter
    def Changes(self, value: ChangesSet_99de0aab) -> None:
        self._changes = value


__all__ = ['ChangesEvent']



# coding: utf-8
#
# Copyright 2023 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Interface Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.4
# Namespace: com.sun.star.view
from __future__ import annotations
import typing
from abc import abstractmethod
from ..lang.x_event_listener import XEventListener as XEventListener_c7230c4a
if typing.TYPE_CHECKING:
    from .print_job_event import PrintJobEvent as PrintJobEvent_bcd60bed

class XPrintJobListener(XEventListener_c7230c4a):
    """
    receives events about print job progress.
    
    XPrintJobListener can be registered to XPrintJobBroadcaster. Then, the client object will be notified when a new print job starts or its state changes.
    
    **since**
    
        OOo 1.1.2

    See Also:
        `API XPrintJobListener <https://api.libreoffice.org/docs/idl/ref/interfacecom_1_1sun_1_1star_1_1view_1_1XPrintJobListener.html>`_
    """
    __ooo_ns__: str = 'com.sun.star.view'
    __ooo_full_ns__: str = 'com.sun.star.view.XPrintJobListener'
    __ooo_type_name__: str = 'interface'
    __pyunointerface__: str = 'com.sun.star.view.XPrintJobListener'

    @abstractmethod
    def printJobEvent(self, Event: PrintJobEvent_bcd60bed) -> None:
        """
        informs the user about the creation or the progress of a PrintJob
        """
        ...

__all__ = ['XPrintJobListener']





# coding: utf-8
#
# Copyright 2023 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Const Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.4
# Namespace: com.sun.star.util


class Endianness(object):
    """
    Const Class

    These constants describe the endianness of data structures.
    
    The endianness specifies the order in which the bytes of larger types are laid out in memory.
    
    **since**
    
        OOo 2.0

    See Also:
        `API Endianness <https://api.libreoffice.org/docs/idl/ref/namespacecom_1_1sun_1_1star_1_1util_1_1Endianness.html>`_
    """
    __ooo_ns__: str = 'com.sun.star.util'
    __ooo_full_ns__: str = 'com.sun.star.util.Endianness'
    __ooo_type_name__: str = 'const'

    LITTLE = 0
    """
    Little endian.
    
    The values are stored in little endian format, i.e. the bytes of the long word 0xAABBCCDD are laid out like 0xDD, 0xCC, 0xBB, 0xAA in memory. That is, data of arbitrary machine word lengths always starts with the least significant byte, and ends with the most significant one.
    """
    BIG = 1
    """
    Big endian.
    
    The values are stored in big endian format, i.e. the bytes of the long word 0xAABBCCDD are laid out like 0xAA, 0xBB, 0xCC, 0xDD in memory. That is, data of arbitrary machine word lengths always start with the most significant byte, and ends with the least significant one.
    """

__all__ = ['Endianness']



# coding: utf-8
#
# Copyright 2023 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Const Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.4
# Namespace: com.sun.star.beans
import uno
from enum import IntEnum
from typing import TYPE_CHECKING
from ooo.oenv.env_const import UNO_ENVIRONMENT, UNO_RUNTIME

_DYNAMIC = False
if (not TYPE_CHECKING) and UNO_RUNTIME and UNO_ENVIRONMENT:
    _DYNAMIC = True

if not TYPE_CHECKING and _DYNAMIC:
    # document generators will most likely not see this.
    from ooo.helper.enum_helper import UnoConstMeta, ConstEnumMeta

    class MethodConcept(metaclass=UnoConstMeta, type_name="com.sun.star.beans.MethodConcept", name_space="com.sun.star.beans"):
        """Dynamic Class. Contains all the constant values of ``com.sun.star.beans.MethodConcept``"""
        pass

    class MethodConceptEnum(IntEnum, metaclass=ConstEnumMeta, type_name="com.sun.star.beans.MethodConcept", name_space="com.sun.star.beans"):
        """Dynamic Enum. Contains all the constant values of ``com.sun.star.beans.MethodConcept`` as Enum values"""
        pass

else:
    if TYPE_CHECKING:
        from com.sun.star.beans import MethodConcept as MethodConcept
    else:
        # keep document generators happy
        from ...lo.beans.method_concept import MethodConcept as MethodConcept

    class MethodConceptEnum(IntEnum):
        """
        Enum of Const Class MethodConcept

        These constants are used to specify concepts of the introspection which apply to methods.
        
        This list is not necessarily complete; new constants may be added.
        """
        ALL = MethodConcept.ALL
        """
        This value is used to query for all methods, see XIntrospectionAccess.getMethod() and XIntrospectionAccess.getMethods()
        """
        DANGEROUS = MethodConcept.DANGEROUS
        """
        specifies methods which can result in an unstable state (i.e.
        
        deadlock, application crash, security hole, etc.) when called directly by the user.
        """
        PROPERTY = MethodConcept.PROPERTY
        """
        specifies methods which are used to set and get the value of properties/attributes.
        
        These methods have the signature type get...() , void set...() or boolean is...() .
        """
        LISTENER = MethodConcept.LISTENER
        """
        specifies methods of the listener concept.
        
        These methods have the signature add...Listener()  or remove...Listener().
        """
        ENUMERATION = MethodConcept.ENUMERATION
        """
        specifies methods of the enumeration concept.
        
        These methods have the signature create...Enumeration and return an interface that is derived from com.sun.star.container.XEnumeration. Additionally, the method com.sun.star.container.XEnumerationAccess.getElementType() belongs to this concept.
        """
        NAMECONTAINER = MethodConcept.NAMECONTAINER
        """
        specifies methods of the name container concept.
        
        These methods have the signature get...ByName(), set...ByName(), replace...ByName(), remove...ByName(), has...ByName(), or get...Names. In addition, the method com.sun.star.container.XEnumerationAccess.getElementType() belongs to this concept.
        """
        INDEXCONTAINER = MethodConcept.INDEXCONTAINER
        """
        specifies methods of the index container concept.
        
        These methods have the signature get...ByIndex(), insert...ByIndex(), replace...ByIndex(), or remove...ByIndex(). The method com.sun.star.container.XIndexAccess.getCount() also belongs to this concept.
        """

__all__ = ['MethodConcept', 'MethodConceptEnum']



# coding: utf-8
#
# Copyright 2023 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Service Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.4
# Namespace: com.sun.star.text
from __future__ import annotations
import typing
from abc import abstractproperty
from .x_document_index import XDocumentIndex as XDocumentIndex_c9330c5c
from ..util.x_refreshable import XRefreshable as XRefreshable_b0d60b81
if typing.TYPE_CHECKING:
    from ..container.x_index_replace import XIndexReplace as XIndexReplace_feed0dd7
    from ..graphic.x_graphic import XGraphic as XGraphic_a4da0afc
    from .x_text_columns import XTextColumns as XTextColumns_b17f0bab
    from .x_text_section import XTextSection as XTextSection_b1730b9f
    from ..util.color import Color as Color_68e908c5
    from com.sun.star.style.GraphicLocation import GraphicLocationProto  # type: ignore

class BaseIndex(XDocumentIndex_c9330c5c, XRefreshable_b0d60b81):
    """
    Service Class

    specifies the basic service of different indexes within a document.
    
    **since**
    
        LibreOffice 4.0

    See Also:
        `API BaseIndex <https://api.libreoffice.org/docs/idl/ref/servicecom_1_1sun_1_1star_1_1text_1_1BaseIndex.html>`_
    """
    __ooo_ns__: str = 'com.sun.star.text'
    __ooo_full_ns__: str = 'com.sun.star.text.BaseIndex'
    __ooo_type_name__: str = 'service'

    @abstractproperty
    def BackColor(self) -> Color_68e908c5:
        """
        specifies the color of the background.
        """
        ...

    @abstractproperty
    def BackGraphic(self) -> XGraphic_a4da0afc:
        """
        contains the graphic object that is displayed as background graphic.
        
        **since**
        
            LibreOffice 6.1
        """
        ...

    @abstractproperty
    def BackGraphicFilter(self) -> str:
        """
        contains the name of the filter of the graphic file that is displayed as background graphic
        """
        ...

    @abstractproperty
    def BackGraphicLocation(self) -> GraphicLocationProto:
        """
        determines the position of the background graphic.
        """
        ...

    @abstractproperty
    def BackGraphicURL(self) -> str:
        """
        contains the URL of a graphic file that is displayed as background graphic
        
        Note the new behaviour since it this was deprecated: This property can only be set and only external URLs are supported (no more vnd.sun.star.GraphicObject scheme). When an URL is set, then it will load the graphic and set the BackGraphic property.
        """
        ...

    @abstractproperty
    def BackTransparent(self) -> bool:
        """
        If TRUE, the background color value in \"BackColor\" is not visible.
        """
        ...

    @abstractproperty
    def ContentSection(self) -> XTextSection_b1730b9f:
        """
        the text section containing the content of the index
        """
        ...

    @abstractproperty
    def CreateFromChapter(self) -> bool:
        """
        determines if the content of the document index is created from the complete document content or from the current chapter only.
        
        It is not available in the bibliography
        """
        ...

    @abstractproperty
    def HeaderSection(self) -> XTextSection_b1730b9f:
        """
        the text section containing the header of the index
        """
        ...

    @abstractproperty
    def IsProtected(self) -> bool:
        """
        determines if the index is protected.
        """
        ...

    @abstractproperty
    def LevelFormat(self) -> XIndexReplace_feed0dd7:
        """
        returns the interface of the level format of the index.
        
        The description of the format of the levels depends on the type of the document index.
        """
        ...

    @abstractproperty
    def ParaStyleHeading(self) -> str:
        """
        contains the name of the paragraph style that is applied to the heading.
        """
        ...

    @abstractproperty
    def ParaStyleLevel1(self) -> str:
        """
        contains the name of the paragraph style that is applied to the 1st level.
        """
        ...

    @abstractproperty
    def ParaStyleLevel10(self) -> str:
        """
        contains the name of the paragraph style that is applied to the 10th level.
        """
        ...

    @abstractproperty
    def ParaStyleLevel2(self) -> str:
        """
        contains the name of the paragraph style that is applied to the 2nd level.
        """
        ...

    @abstractproperty
    def ParaStyleLevel3(self) -> str:
        """
        contains the name of the paragraph style that is applied to the 3rd level.
        """
        ...

    @abstractproperty
    def ParaStyleLevel4(self) -> str:
        """
        contains the name of the paragraph style that is applied to the 4th level.
        """
        ...

    @abstractproperty
    def ParaStyleLevel5(self) -> str:
        """
        contains the name of the paragraph style that is applied to the 5th level.
        """
        ...

    @abstractproperty
    def ParaStyleLevel6(self) -> str:
        """
        contains the name of the paragraph style that is applied to the 6th level.
        """
        ...

    @abstractproperty
    def ParaStyleLevel7(self) -> str:
        """
        contains the name of the paragraph style that is applied to the 7th level.
        """
        ...

    @abstractproperty
    def ParaStyleLevel8(self) -> str:
        """
        contains the name of the paragraph style that is applied to the 8th level.
        """
        ...

    @abstractproperty
    def ParaStyleLevel9(self) -> str:
        """
        contains the name of the paragraph style that is applied to the 9th level.
        """
        ...

    @abstractproperty
    def ParaStyleSeparator(self) -> str:
        """
        contains the name of the paragraph style that is applied to the separator level.
        """
        ...

    @abstractproperty
    def TextColumns(self) -> XTextColumns_b17f0bab:
        """
        contains the column interface.
        """
        ...

    @abstractproperty
    def Title(self) -> str:
        """
        contains the title of the index.
        """
        ...


__all__ = ['BaseIndex']


# coding: utf-8
#
# Copyright 2023 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Struct Class
# this is a auto generated file generated by Cheetah
# Namespace: com.sun.star.frame
# Libre Office Version: 7.4
from ooo.oenv.env_const import UNO_NONE
import typing


class BorderWidths(object):
    """
    Struct Class

    specifies a border area by offsets from each side.

    See Also:
        `API BorderWidths <https://api.libreoffice.org/docs/idl/ref/structcom_1_1sun_1_1star_1_1frame_1_1BorderWidths.html>`_
    """
    __ooo_ns__: str = 'com.sun.star.frame'
    __ooo_full_ns__: str = 'com.sun.star.frame.BorderWidths'
    __ooo_type_name__: str = 'struct'
    typeName: str = 'com.sun.star.frame.BorderWidths'
    """Literal Constant ``com.sun.star.frame.BorderWidths``"""

    def __init__(self, Left: typing.Optional[int] = 0, Top: typing.Optional[int] = 0, Right: typing.Optional[int] = 0, Bottom: typing.Optional[int] = 0) -> None:
        """
        Constructor

        Arguments:
            Left (int, optional): Left value.
            Top (int, optional): Top value.
            Right (int, optional): Right value.
            Bottom (int, optional): Bottom value.
        """
        super().__init__()

        if isinstance(Left, BorderWidths):
            oth: BorderWidths = Left
            self.Left = oth.Left
            self.Top = oth.Top
            self.Right = oth.Right
            self.Bottom = oth.Bottom
            return

        kargs = {
            "Left": Left,
            "Top": Top,
            "Right": Right,
            "Bottom": Bottom,
        }
        self._init(**kargs)

    def _init(self, **kwargs) -> None:
        self._left = kwargs["Left"]
        self._top = kwargs["Top"]
        self._right = kwargs["Right"]
        self._bottom = kwargs["Bottom"]


    @property
    def Left(self) -> int:
        """
        specifies the offset from left border.
        """
        return self._left

    @Left.setter
    def Left(self, value: int) -> None:
        self._left = value

    @property
    def Top(self) -> int:
        """
        specifies the offset from top border.
        """
        return self._top

    @Top.setter
    def Top(self, value: int) -> None:
        self._top = value

    @property
    def Right(self) -> int:
        """
        specifies the offset from right border.
        """
        return self._right

    @Right.setter
    def Right(self, value: int) -> None:
        self._right = value

    @property
    def Bottom(self) -> int:
        """
        specifies the offset from bottom border.
        """
        return self._bottom

    @Bottom.setter
    def Bottom(self, value: int) -> None:
        self._bottom = value


__all__ = ['BorderWidths']



# coding: utf-8
#
# Copyright 2023 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Service Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.4
# Namespace: com.sun.star.form.control
from __future__ import annotations
from ...awt.uno_control import UnoControl as UnoControl_8f2c0a67
from ...container.x_enumeration_access import XEnumerationAccess as XEnumerationAccess_4bac0ffc
from ...container.x_index_access import XIndexAccess as XIndexAccess_f0910d6d
from ..x_bound_component import XBoundComponent as XBoundComponent_d4830cbf
from ..x_grid import XGrid as XGrid_6836089a
from ..x_grid_control import XGridControl as XGridControl_af710b7b
from ..x_grid_field_data_supplier import XGridFieldDataSupplier as XGridFieldDataSupplier_34aa0f4c
from ...frame.x_dispatch_provider_interception import XDispatchProviderInterception as XDispatchProviderInterception_c2a512da
from ...util.x_mode_selector import XModeSelector as XModeSelector_bbdc0be4
from ...util.x_modify_broadcaster import XModifyBroadcaster as XModifyBroadcaster_fd990df0
from ...view.x_selection_supplier import XSelectionSupplier as XSelectionSupplier_fed20e15

class GridControl(UnoControl_8f2c0a67, XBoundComponent_d4830cbf, XGridControl_af710b7b, XGrid_6836089a, XGridFieldDataSupplier_34aa0f4c, XEnumerationAccess_4bac0ffc, XDispatchProviderInterception_c2a512da, XIndexAccess_f0910d6d, XSelectionSupplier_fed20e15, XModeSelector_bbdc0be4, XModifyBroadcaster_fd990df0):
    """
    Service Class

    describes a table-like control for displaying data.
    
    The model of the control has to support the com.sun.star.form.component.GridControl service.

    See Also:
        `API GridControl <https://api.libreoffice.org/docs/idl/ref/servicecom_1_1sun_1_1star_1_1form_1_1control_1_1GridControl.html>`_
    """
    __ooo_ns__: str = 'com.sun.star.form.control'
    __ooo_full_ns__: str = 'com.sun.star.form.control.GridControl'
    __ooo_type_name__: str = 'service'


__all__ = ['GridControl']




# coding: utf-8
#
# Copyright 2023 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Service Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.4
# Namespace: com.sun.star.presentation
from __future__ import annotations
from abc import abstractproperty
from ..document.header_footer_settings import HeaderFooterSettings as HeaderFooterSettings_5acd1070
from ..document.settings import Settings as Settings_b2bc0bb8

class DocumentSettings(HeaderFooterSettings_5acd1070, Settings_b2bc0bb8):
    """
    Service Class

    describes properties that apply to the whole presentation document.

    See Also:
        `API DocumentSettings <https://api.libreoffice.org/docs/idl/ref/servicecom_1_1sun_1_1star_1_1presentation_1_1DocumentSettings.html>`_
    """
    __ooo_ns__: str = 'com.sun.star.presentation'
    __ooo_full_ns__: str = 'com.sun.star.presentation.DocumentSettings'
    __ooo_type_name__: str = 'service'

    @abstractproperty
    def IsPrintDrawing(self) -> bool:
        """
        enables or disables the printing of the drawing pages
        """
        ...

    @abstractproperty
    def IsPrintFitPage(self) -> bool:
        """
        enables or disables the fitting of the page to the printable area during print
        """
        ...

    @abstractproperty
    def IsPrintHandout(self) -> bool:
        """
        enables or disables the printing of the handout pages
        """
        ...

    @abstractproperty
    def IsPrintHiddenPages(self) -> bool:
        """
        enables or disables the printing of draw pages that are marked hidden
        """
        ...

    @abstractproperty
    def IsPrintNotes(self) -> bool:
        """
        enables or disables the printing of the notes pages
        """
        ...

    @abstractproperty
    def IsPrintOutline(self) -> bool:
        """
        enables or disables the printing of the outline pages
        """
        ...

    @abstractproperty
    def IsPrintTilePage(self) -> bool:
        """
        if this is true and the paper size for printing is larger than the paper size of the printer than the content is tiled over multiple pages.
        """
        ...

    @abstractproperty
    def PageNumberFormat(self) -> int:
        """
        is the number format used for page number fields
        
        Values 0-7 are supported.
        """
        ...

    @abstractproperty
    def ParagraphSummation(self) -> bool:
        """
        If this is true, the distance between two paragraphs is the sum of ParaBottomMargin of the previous and ParaTopMargin of the next paragraph.
        
        If false, only the greater of the two is chosen.
        """
        ...


__all__ = ['DocumentSettings']




# coding: utf-8
#
# Copyright 2023 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Const Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.4
# Namespace: com.sun.star.i18n


class LocaleItem(object):
    """
    Const Class

    These are not used with the API but with an OOo internal wrapper class that caches the contents of an instance of LocaleDataItem and uses these values to access it's members for faster access.
    
    Whenever locale data items were added these values and the wrapper class would have to be adjusted to give the application an easier access.
    
    .. deprecated::
    
        Class is deprecated.

    See Also:
        `API LocaleItem <https://api.libreoffice.org/docs/idl/ref/namespacecom_1_1sun_1_1star_1_1i18n_1_1LocaleItem.html>`_
    """
    __ooo_ns__: str = 'com.sun.star.i18n'
    __ooo_full_ns__: str = 'com.sun.star.i18n.LocaleItem'
    __ooo_type_name__: str = 'const'

    DATE_SEPARATOR = 0
    THOUSAND_SEPARATOR = 1
    DECIMAL_SEPARATOR = 2
    TIME_SEPARATOR = 3
    TIME_100SEC_SEPARATOR = 4
    LIST_SEPARATOR = 5
    SINGLE_QUOTATION_START = 6
    SINGLE_QUOTATION_END = 7
    DOUBLE_QUOTATION_START = 8
    DOUBLE_QUOTATION_END = 9
    MEASUREMENT_SYSTEM = 10
    TIME_AM = 11
    TIME_PM = 12
    LONG_DATE_DAY_OF_WEEK_SEPARATOR = 13
    LONG_DATE_DAY_SEPARATOR = 14
    LONG_DATE_MONTH_SEPARATOR = 15
    LONG_DATE_YEAR_SEPARATOR = 16
    COUNT = 17
    """
    count of items available
    """
    DECIMAL_SEPARATOR_ALTERNATIVE = 17
    COUNT2 = 18
    """
    count of items available
    """

__all__ = ['LocaleItem']



# coding: utf-8
#
# Copyright 2023 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Const Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.4
# Namespace: com.sun.star.frame
import uno
from enum import IntEnum
from typing import TYPE_CHECKING
from ooo.oenv.env_const import UNO_ENVIRONMENT, UNO_RUNTIME

_DYNAMIC = False
if (not TYPE_CHECKING) and UNO_RUNTIME and UNO_ENVIRONMENT:
    _DYNAMIC = True

if not TYPE_CHECKING and _DYNAMIC:
    # document generators will most likely not see this.
    from ooo.helper.enum_helper import UnoConstMeta, ConstEnumMeta

    class LayoutManagerEvents(metaclass=UnoConstMeta, type_name="com.sun.star.frame.LayoutManagerEvents", name_space="com.sun.star.frame"):
        """Dynamic Class. Contains all the constant values of ``com.sun.star.frame.LayoutManagerEvents``"""
        pass

    class LayoutManagerEventsEnum(IntEnum, metaclass=ConstEnumMeta, type_name="com.sun.star.frame.LayoutManagerEvents", name_space="com.sun.star.frame"):
        """Dynamic Enum. Contains all the constant values of ``com.sun.star.frame.LayoutManagerEvents`` as Enum values"""
        pass

else:
    if TYPE_CHECKING:
        from com.sun.star.frame import LayoutManagerEvents as LayoutManagerEvents
    else:
        # keep document generators happy
        from ...lo.frame.layout_manager_events import LayoutManagerEvents as LayoutManagerEvents

    class LayoutManagerEventsEnum(IntEnum):
        """
        Enum of Const Class LayoutManagerEvents

        provides information about layout manager events
        
        Events are provided only for notification purposes only.
        
        **since**
        
            OOo 2.0
        """
        LOCK = LayoutManagerEvents.LOCK
        """
        specifies that the layout manager processed a lock call, which prevents it from doing layouts.
        
        This event sends the current lock count as additional information.
        """
        UNLOCK = LayoutManagerEvents.UNLOCK
        """
        specifies that the layout manager processed an unlock call, which admit layouts when the lock count is zero.
        
        This event sends the current lock count as additional information.
        """
        LAYOUT = LayoutManagerEvents.LAYOUT
        """
        specifies that the layout manager refreshed the layout of the frame.
        
        This event sends no additional information.
        """
        VISIBLE = LayoutManagerEvents.VISIBLE
        """
        specifies that the layout manager container frame window becomes visible.
        
        This event sends no additional information.
        """
        INVISIBLE = LayoutManagerEvents.INVISIBLE
        """
        specifies that the layout manager container frame window becomes invisible.
        
        This event sends no additional information.
        """
        MERGEDMENUBAR = LayoutManagerEvents.MERGEDMENUBAR
        """
        A merged menu bar has been set at the layout manager.
        
        This event sends no additional information.
        """
        UIELEMENT_VISIBLE = LayoutManagerEvents.UIELEMENT_VISIBLE
        """
        specifies that a certain user interface element has been made visible
        
        This event sends the resource url of the newly visible user interface element.
        """
        UIELEMENT_INVISIBLE = LayoutManagerEvents.UIELEMENT_INVISIBLE
        """
        specifies that a certain user interface element has been made invisible
        
        This event sends the resource url of the invisible user interface element.
        """

__all__ = ['LayoutManagerEvents', 'LayoutManagerEventsEnum']



# coding: utf-8
#
# Copyright 2023 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Service Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.4
# Namespace: com.sun.star.awt
from __future__ import annotations
import typing
from abc import abstractproperty
from .uno_control_model import UnoControlModel as UnoControlModel_c8ce0c58
if typing.TYPE_CHECKING:
    from ..util.color import Color as Color_68e908c5

class UnoControlContainerModel(UnoControlModel_c8ce0c58):
    """
    Service Class

    specifies the standard model of a UnoControlContainer.
    
    **since**
    
        OOo 2.0

    See Also:
        `API UnoControlContainerModel <https://api.libreoffice.org/docs/idl/ref/servicecom_1_1sun_1_1star_1_1awt_1_1UnoControlContainerModel.html>`_
    """
    __ooo_ns__: str = 'com.sun.star.awt'
    __ooo_full_ns__: str = 'com.sun.star.awt.UnoControlContainerModel'
    __ooo_type_name__: str = 'service'

    @abstractproperty
    def BackgroundColor(self) -> Color_68e908c5:
        """
        specifies the background color (RGB) of the control.
        """
        ...

    @abstractproperty
    def Border(self) -> int:
        """
        specifies the border style of the control.
        """
        ...

    @abstractproperty
    def BorderColor(self) -> int:
        """
        specifies the color of the border, if present
        
        Not every border style (see Border) may support coloring. For instance, usually a border with 3D effect will ignore the BorderColor setting.
        
        **since**
        
            OOo 2.0
        """
        ...

    @abstractproperty
    def Enabled(self) -> bool:
        """
        determines whether a control is enabled or disabled.
        """
        ...

    @abstractproperty
    def HelpText(self) -> str:
        """
        specifies the help text of the control.
        """
        ...

    @abstractproperty
    def HelpURL(self) -> str:
        """
        specifies the help URL of the control.
        """
        ...

    @abstractproperty
    def Printable(self) -> bool:
        """
        specifies whether the control will be printed with the document.
        """
        ...

    @abstractproperty
    def Text(self) -> str:
        """
        specifies the text displayed in the control.
        """
        ...


__all__ = ['UnoControlContainerModel']




# coding: utf-8
#
# Copyright 2023 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Interface Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.4
# Namespace: com.sun.star.sheet
from __future__ import annotations
from abc import abstractmethod
from ..uno.x_interface import XInterface as XInterface_8f010a43

class XExternalSheetName(XInterface_8f010a43):
    """
    provides a method to set an external name at the sheet.
    
    An external reference in a cell formula is implemented using a hidden sheet which is linked to the sheet in the external document. The name of the hidden sheet is composed of the URL of the external document and the external sheet name.
    
    **since**
    
        OOo 3.0

    See Also:
        `API XExternalSheetName <https://api.libreoffice.org/docs/idl/ref/interfacecom_1_1sun_1_1star_1_1sheet_1_1XExternalSheetName.html>`_
    """
    __ooo_ns__: str = 'com.sun.star.sheet'
    __ooo_full_ns__: str = 'com.sun.star.sheet.XExternalSheetName'
    __ooo_type_name__: str = 'interface'
    __pyunointerface__: str = 'com.sun.star.sheet.XExternalSheetName'

    @abstractmethod
    def setExternalName(self, aUrl: str, aSheetName: str) -> None:
        """
        sets an external name at the sheet.
        
        This method allows to compose the sheet name from the URL of the external document and the name of the external sheet.

        Raises:
            com.sun.star.container.ElementExistException: ``ElementExistException``
        """
        ...

__all__ = ['XExternalSheetName']





# coding: utf-8
#
# Copyright 2023 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Service Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.4
# Namespace: com.sun.star.sdb
from __future__ import annotations
from ..frame.x_controller import XController as XController_b00e0b8f
from ..lang.x_initialization import XInitialization as XInitialization_d46c0cca

class TableDesign(XController_b00e0b8f, XInitialization_d46c0cca):
    """
    Service Class

    implements a component which allows the creation of tables.
    
    This service implements a user interface for creating tables through a graphical design interface.
    
    The design view of the TableDesign is divided into two parts. The first part contains the rows where columns can be defined for the table. The second part contains the properties of the selected column.
    
    **since**
    
        OOo 1.1.2

    See Also:
        `API TableDesign <https://api.libreoffice.org/docs/idl/ref/servicecom_1_1sun_1_1star_1_1sdb_1_1TableDesign.html>`_
    """
    __ooo_ns__: str = 'com.sun.star.sdb'
    __ooo_full_ns__: str = 'com.sun.star.sdb.TableDesign'
    __ooo_type_name__: str = 'service'


__all__ = ['TableDesign']




# coding: utf-8
#
# Copyright 2023 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Interface Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.4
# Namespace: com.sun.star.document
from __future__ import annotations
import typing
from abc import abstractmethod, abstractproperty
from .x_embedded_object_supplier import XEmbeddedObjectSupplier as XEmbeddedObjectSupplier_8b631174
if typing.TYPE_CHECKING:
    from ..embed.x_embedded_object import XEmbeddedObject as XEmbeddedObject_ddee0cbe
    from ..graphic.x_graphic import XGraphic as XGraphic_a4da0afc

class XEmbeddedObjectSupplier2(XEmbeddedObjectSupplier_8b631174):
    """
    represents something that provides an embedded object.

    See Also:
        `API XEmbeddedObjectSupplier2 <https://api.libreoffice.org/docs/idl/ref/interfacecom_1_1sun_1_1star_1_1document_1_1XEmbeddedObjectSupplier2.html>`_
    """
    __ooo_ns__: str = 'com.sun.star.document'
    __ooo_full_ns__: str = 'com.sun.star.document.XEmbeddedObjectSupplier2'
    __ooo_type_name__: str = 'interface'
    __pyunointerface__: str = 'com.sun.star.document.XEmbeddedObjectSupplier2'

    @abstractmethod
    def getExtendedControlOverEmbeddedObject(self) -> XEmbeddedObject_ddee0cbe:
        """
        returns the object which is embedded into this object.
        
        This method does not return the model that is controlled by the embedded object, but the embedded object itself.
        """
        ...
    @abstractproperty
    def Aspect(self) -> int:
        """
        allows to control the aspect of the object.
        """
        ...

    @abstractproperty
    def ReplacementGraphic(self) -> XGraphic_a4da0afc:
        """
        allows to get the replacement image of the object.
        """
        ...


__all__ = ['XEmbeddedObjectSupplier2']





# coding: utf-8
#
# Copyright 2023 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Struct Class
# this is a auto generated file generated by Cheetah
# Namespace: com.sun.star.awt
# Libre Office Version: 7.4
from ooo.oenv.env_const import UNO_NONE
from ..lang.event_object import EventObject as EventObject_a3d70b03
from ..uno.x_interface import XInterface as XInterface_8f010a43
import typing


class WindowEvent(EventObject_a3d70b03):
    """
    Struct Class

    specifies a window event.

    See Also:
        `API WindowEvent <https://api.libreoffice.org/docs/idl/ref/structcom_1_1sun_1_1star_1_1awt_1_1WindowEvent.html>`_
    """
    __ooo_ns__: str = 'com.sun.star.awt'
    __ooo_full_ns__: str = 'com.sun.star.awt.WindowEvent'
    __ooo_type_name__: str = 'struct'
    typeName: str = 'com.sun.star.awt.WindowEvent'
    """Literal Constant ``com.sun.star.awt.WindowEvent``"""

    def __init__(self, Source: typing.Optional[XInterface_8f010a43] = None, X: typing.Optional[int] = 0, Y: typing.Optional[int] = 0, Width: typing.Optional[int] = 0, Height: typing.Optional[int] = 0, LeftInset: typing.Optional[int] = 0, TopInset: typing.Optional[int] = 0, RightInset: typing.Optional[int] = 0, BottomInset: typing.Optional[int] = 0) -> None:
        """
        Constructor

        Arguments:
            Source (XInterface, optional): Source value.
            X (int, optional): X value.
            Y (int, optional): Y value.
            Width (int, optional): Width value.
            Height (int, optional): Height value.
            LeftInset (int, optional): LeftInset value.
            TopInset (int, optional): TopInset value.
            RightInset (int, optional): RightInset value.
            BottomInset (int, optional): BottomInset value.
        """

        if isinstance(Source, WindowEvent):
            oth: WindowEvent = Source
            self.Source = oth.Source
            self.X = oth.X
            self.Y = oth.Y
            self.Width = oth.Width
            self.Height = oth.Height
            self.LeftInset = oth.LeftInset
            self.TopInset = oth.TopInset
            self.RightInset = oth.RightInset
            self.BottomInset = oth.BottomInset
            return

        kargs = {
            "Source": Source,
            "X": X,
            "Y": Y,
            "Width": Width,
            "Height": Height,
            "LeftInset": LeftInset,
            "TopInset": TopInset,
            "RightInset": RightInset,
            "BottomInset": BottomInset,
        }
        self._init(**kargs)

    def _init(self, **kwargs) -> None:
        self._x = kwargs["X"]
        self._y = kwargs["Y"]
        self._width = kwargs["Width"]
        self._height = kwargs["Height"]
        self._left_inset = kwargs["LeftInset"]
        self._top_inset = kwargs["TopInset"]
        self._right_inset = kwargs["RightInset"]
        self._bottom_inset = kwargs["BottomInset"]
        inst_keys = ('X', 'Y', 'Width', 'Height', 'LeftInset', 'TopInset', 'RightInset', 'BottomInset')
        kargs = kwargs.copy()
        for key in inst_keys:
            del kargs[key]
        super()._init(**kargs)


    @property
    def X(self) -> int:
        """
        specifies the outer x position of the window.
        """
        return self._x

    @X.setter
    def X(self, value: int) -> None:
        self._x = value

    @property
    def Y(self) -> int:
        """
        specifies the outer y position of the window.
        """
        return self._y

    @Y.setter
    def Y(self, value: int) -> None:
        self._y = value

    @property
    def Width(self) -> int:
        """
        specifies the outer (total) width of the window.
        """
        return self._width

    @Width.setter
    def Width(self, value: int) -> None:
        self._width = value

    @property
    def Height(self) -> int:
        """
        specifies the outer (total) height of the window.
        """
        return self._height

    @Height.setter
    def Height(self, value: int) -> None:
        self._height = value

    @property
    def LeftInset(self) -> int:
        """
        specifies the inset from the left.
        
        The inset is the distance between the outer and the inner window, that means the left inset is the width of the left border.
        """
        return self._left_inset

    @LeftInset.setter
    def LeftInset(self, value: int) -> None:
        self._left_inset = value

    @property
    def TopInset(self) -> int:
        """
        specifies the inset from the top.
        
        The inset is the distance between the outer and the inner window, that means the top inset is the height of the top border.
        """
        return self._top_inset

    @TopInset.setter
    def TopInset(self, value: int) -> None:
        self._top_inset = value

    @property
    def RightInset(self) -> int:
        """
        specifies the inset from the right.
        
        The inset is the distance between the outer and the inner window, that means the right inset is the width of the right border.
        """
        return self._right_inset

    @RightInset.setter
    def RightInset(self, value: int) -> None:
        self._right_inset = value

    @property
    def BottomInset(self) -> int:
        """
        specifies the inset from the bottom.
        
        The inset is the distance between the outer and the inner window, that means the bottom inset is the height of the bottom border.
        """
        return self._bottom_inset

    @BottomInset.setter
    def BottomInset(self, value: int) -> None:
        self._bottom_inset = value


__all__ = ['WindowEvent']



# coding: utf-8
#
# Copyright 2023 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Service Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.4
# Namespace: com.sun.star.drawing
from __future__ import annotations
from .line_properties import LineProperties as LineProperties_f13f0da9
from .poly_polygon_bezier_descriptor import PolyPolygonBezierDescriptor as PolyPolygonBezierDescriptor_c7e61300
from .rotation_descriptor import RotationDescriptor as RotationDescriptor_2cec0f63
from .shadow_properties import ShadowProperties as ShadowProperties_e350e87
from .shape import Shape as Shape_85cc09e5
from .text import Text as Text_7c140999

class OpenBezierShape(LineProperties_f13f0da9, PolyPolygonBezierDescriptor_c7e61300, RotationDescriptor_2cec0f63, ShadowProperties_e350e87, Shape_85cc09e5, Text_7c140999):
    """
    Service Class

    This service is for an open Bezier shape.

    See Also:
        `API OpenBezierShape <https://api.libreoffice.org/docs/idl/ref/servicecom_1_1sun_1_1star_1_1drawing_1_1OpenBezierShape.html>`_
    """
    __ooo_ns__: str = 'com.sun.star.drawing'
    __ooo_full_ns__: str = 'com.sun.star.drawing.OpenBezierShape'
    __ooo_type_name__: str = 'service'


__all__ = ['OpenBezierShape']




# coding: utf-8
#
# Copyright 2023 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Struct Class
# this is a auto generated file generated by Cheetah
# Namespace: com.sun.star.linguistic2
# Libre Office Version: 7.4
from ooo.oenv.env_const import UNO_NONE
from ..lang.event_object import EventObject as EventObject_a3d70b03
from ..uno.x_interface import XInterface as XInterface_8f010a43
import typing
from .x_dictionary_entry import XDictionaryEntry as XDictionaryEntry_49ef0ff5


class DictionaryEvent(EventObject_a3d70b03):
    """
    Struct Class

    represents a dictionary event.
    
    This type of event is used by a dictionary to inform its listeners about changes in its properties or its entry list. It consists of an event type and may supply an affected dictionary entry.

    See Also:
        `API DictionaryEvent <https://api.libreoffice.org/docs/idl/ref/structcom_1_1sun_1_1star_1_1linguistic2_1_1DictionaryEvent.html>`_
    """
    __ooo_ns__: str = 'com.sun.star.linguistic2'
    __ooo_full_ns__: str = 'com.sun.star.linguistic2.DictionaryEvent'
    __ooo_type_name__: str = 'struct'
    typeName: str = 'com.sun.star.linguistic2.DictionaryEvent'
    """Literal Constant ``com.sun.star.linguistic2.DictionaryEvent``"""

    def __init__(self, Source: typing.Optional[XInterface_8f010a43] = None, nEvent: typing.Optional[int] = 0, xDictionaryEntry: typing.Optional[XDictionaryEntry_49ef0ff5] = None) -> None:
        """
        Constructor

        Arguments:
            Source (XInterface, optional): Source value.
            nEvent (int, optional): nEvent value.
            xDictionaryEntry (XDictionaryEntry, optional): xDictionaryEntry value.
        """

        if isinstance(Source, DictionaryEvent):
            oth: DictionaryEvent = Source
            self.Source = oth.Source
            self.nEvent = oth.nEvent
            self.xDictionaryEntry = oth.xDictionaryEntry
            return

        kargs = {
            "Source": Source,
            "nEvent": nEvent,
            "xDictionaryEntry": xDictionaryEntry,
        }
        self._init(**kargs)

    def _init(self, **kwargs) -> None:
        self._n_event = kwargs["nEvent"]
        self._x_dictionary_entry = kwargs["xDictionaryEntry"]
        inst_keys = ('nEvent', 'xDictionaryEntry')
        kargs = kwargs.copy()
        for key in inst_keys:
            del kargs[key]
        super()._init(**kargs)


    @property
    def nEvent(self) -> int:
        """
        is the type of event.
        
        This must be the value of a single flag. No combinations are allowed.
        """
        return self._n_event

    @nEvent.setter
    def nEvent(self, value: int) -> None:
        self._n_event = value

    @property
    def xDictionaryEntry(self) -> XDictionaryEntry_49ef0ff5:
        """
        is the affected dictionary entry (if any).
        
        It must be set if an entry was added or deleted, otherwise it should be empty.
        """
        return self._x_dictionary_entry

    @xDictionaryEntry.setter
    def xDictionaryEntry(self, value: XDictionaryEntry_49ef0ff5) -> None:
        self._x_dictionary_entry = value


__all__ = ['DictionaryEvent']



# coding: utf-8
#
# Copyright 2023 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Struct Class
# this is a auto generated file generated by Cheetah
# Namespace: com.sun.star.reflection
# Libre Office Version: 7.4
from ooo.oenv.env_const import UNO_NONE
import typing
from .param_mode import ParamMode as ParamMode_d7260ca9
from .x_idl_class import XIdlClass as XIdlClass_d63a0c9a


class ParamInfo(object):
    """
    Struct Class

    Provides information about a formal parameter of a method.

    See Also:
        `API ParamInfo <https://api.libreoffice.org/docs/idl/ref/structcom_1_1sun_1_1star_1_1reflection_1_1ParamInfo.html>`_
    """
    __ooo_ns__: str = 'com.sun.star.reflection'
    __ooo_full_ns__: str = 'com.sun.star.reflection.ParamInfo'
    __ooo_type_name__: str = 'struct'
    typeName: str = 'com.sun.star.reflection.ParamInfo'
    """Literal Constant ``com.sun.star.reflection.ParamInfo``"""

    def __init__(self, aName: typing.Optional[str] = '', aMode: typing.Optional[ParamMode_d7260ca9] = ParamMode_d7260ca9.IN, aType: typing.Optional[XIdlClass_d63a0c9a] = None) -> None:
        """
        Constructor

        Arguments:
            aName (str, optional): aName value.
            aMode (ParamMode, optional): aMode value.
            aType (XIdlClass, optional): aType value.
        """
        super().__init__()

        if isinstance(aName, ParamInfo):
            oth: ParamInfo = aName
            self.aName = oth.aName
            self.aMode = oth.aMode
            self.aType = oth.aType
            return

        kargs = {
            "aName": aName,
            "aMode": aMode,
            "aType": aType,
        }
        self._init(**kargs)

    def _init(self, **kwargs) -> None:
        self._a_name = kwargs["aName"]
        self._a_mode = kwargs["aMode"]
        self._a_type = kwargs["aType"]


    @property
    def aName(self) -> str:
        """
        name of the parameter
        """
        return self._a_name

    @aName.setter
    def aName(self, value: str) -> None:
        self._a_name = value

    @property
    def aMode(self) -> ParamMode_d7260ca9:
        """
        parameter mode: in, out, inout
        """
        return self._a_mode

    @aMode.setter
    def aMode(self, value: ParamMode_d7260ca9) -> None:
        self._a_mode = value

    @property
    def aType(self) -> XIdlClass_d63a0c9a:
        """
        formal type of the parameter
        """
        return self._a_type

    @aType.setter
    def aType(self, value: XIdlClass_d63a0c9a) -> None:
        self._a_type = value


__all__ = ['ParamInfo']



# coding: utf-8
#
# Copyright 2023 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Service Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.4
# Namespace: com.sun.star.presentation
from __future__ import annotations
import typing
from abc import abstractproperty, ABC
if typing.TYPE_CHECKING:
    from ..util.color import Color as Color_68e908c5
    from com.sun.star.presentation.AnimationEffect import AnimationEffectProto  # type: ignore
    from com.sun.star.presentation.ClickAction import ClickActionProto  # type: ignore
    from com.sun.star.presentation.AnimationSpeed import AnimationSpeedProto  # type: ignore

class Shape(ABC):
    """
    Service Class

    this service is supported from all shapes inside a PresentationDocument.
    
    This usually enhances objects of type com.sun.star.drawing.Shape with presentation properties.

    See Also:
        `API Shape <https://api.libreoffice.org/docs/idl/ref/servicecom_1_1sun_1_1star_1_1presentation_1_1Shape.html>`_
    """
    __ooo_ns__: str = 'com.sun.star.presentation'
    __ooo_full_ns__: str = 'com.sun.star.presentation.Shape'
    __ooo_type_name__: str = 'service'

    @abstractproperty
    def Bookmark(self) -> str:
        """
        is a generic URL for the property OnClick.
        """
        ...

    @abstractproperty
    def DimColor(self) -> Color_68e908c5:
        """
        This is the color for dimming this shape.
        
        This color is used if the property com.sun.star.drawing.Shape.DimPrev is TRUE and com.sun.star.drawing.Shape.DimHide is FALSE.
        """
        ...

    @abstractproperty
    def DimHide(self) -> bool:
        """
        If this property and the property com.sun.star.drawing.Shape.DimPrev are both TRUE, the shape is hidden instead of dimmed to a color.
        """
        ...

    @abstractproperty
    def DimPrevious(self) -> bool:
        """
        If this property is TRUE, this shape is dimmed to the color of property com.sun.star.drawing.Shape.DimColor after executing its animation effect.
        """
        ...

    @abstractproperty
    def Effect(self) -> AnimationEffectProto:
        """
        selects the animation effect of this shape.
        """
        ...

    @abstractproperty
    def IsEmptyPresentationObject(self) -> bool:
        """
        If this is a default presentation object and if it is empty, this property is TRUE.
        """
        ...

    @abstractproperty
    def IsPresentationObject(self) -> bool:
        """
        If this is a presentation object, this property is TRUE.
        
        Presentation objects are objects like TitleTextShape and OutlinerShape.
        """
        ...

    @abstractproperty
    def OnClick(self) -> ClickActionProto:
        """
        selects an action performed after the user clicks on this shape.
        """
        ...

    @abstractproperty
    def PlayFull(self) -> bool:
        """
        If this property is TRUE, the sound of this shape is played in full.
        
        The default behavior is to stop the sound after completing the animation effect.
        """
        ...

    @abstractproperty
    def PresentationOrder(self) -> int:
        """
        This is the position of this shape in the order of the shapes which can be animated on its page.
        
        The animations are executed in this order, starting at the shape with the PresentationOrder \"one.\" You can change the order by changing this number. Setting it to \"one\" makes this shape the first shape in the execution order for the animation effects.
        """
        ...

    @abstractproperty
    def Sound(self) -> str:
        """
        This is the URL to a sound file that is played while the animation effect of this shape is running.
        """
        ...

    @abstractproperty
    def SoundOn(self) -> bool:
        """
        If this property is set to TRUE, a sound is played while the animation effect is executed.
        """
        ...

    @abstractproperty
    def Speed(self) -> AnimationSpeedProto:
        """
        This is the speed of the animation effect.
        """
        ...

    @abstractproperty
    def TextEffect(self) -> AnimationEffectProto:
        """
        This is the animation effect for the text inside this shape.
        """
        ...

    @abstractproperty
    def Verb(self) -> int:
        """
        specifies an \"OLE2\" verb for the ClickAction VERB in the property com.sun.star.drawing.Shape.OnClick.
        """
        ...


__all__ = ['Shape']


# coding: utf-8
#
# Copyright 2023 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Interface Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.4
# Namespace: com.sun.star.sdbc
from __future__ import annotations
import typing
from abc import abstractmethod
from .x_result_set import XResultSet as XResultSet_98e30aa7
if typing.TYPE_CHECKING:
    from .x_row_set_listener import XRowSetListener as XRowSetListener_d3580ca6

class XRowSet(XResultSet_98e30aa7):
    """
    enhances the functionality of a result set.
    
    It allows implementation of a special behavior for a result set and notifies an application on certain row set events such as a change in its value.
    
    The XRowSet interface is unique in that it is intended to be a software layer on top of an SDBC driver. Implementations of the RowSet interface can be provided by anyone.

    See Also:
        `API XRowSet <https://api.libreoffice.org/docs/idl/ref/interfacecom_1_1sun_1_1star_1_1sdbc_1_1XRowSet.html>`_
    """
    __ooo_ns__: str = 'com.sun.star.sdbc'
    __ooo_full_ns__: str = 'com.sun.star.sdbc.XRowSet'
    __ooo_type_name__: str = 'interface'
    __pyunointerface__: str = 'com.sun.star.sdbc.XRowSet'

    @abstractmethod
    def addRowSetListener(self, listener: XRowSetListener_d3580ca6) -> None:
        """
        adds the specified listener to receive the events \"cursorMoved\", \"rowChanged\", and \"rowSetChanged\".
        """
        ...
    @abstractmethod
    def execute(self) -> None:
        """
        populates a row set with data.
        
        The description of the data source and other important information for filling the row set with data.

        Raises:
            SQLException: ``SQLException``
        """
        ...
    @abstractmethod
    def removeRowSetListener(self, listener: XRowSetListener_d3580ca6) -> None:
        """
        removes the specified listener.
        """
        ...

__all__ = ['XRowSet']





# coding: utf-8
#
# Copyright 2023 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Interface Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.4
# Namespace: com.sun.star.inspection
from __future__ import annotations
import typing
from abc import abstractmethod
from ..lang.x_component import XComponent as XComponent_98dc0ab5
if typing.TYPE_CHECKING:
    from ..beans.property import Property as Property_8f4e0a76
    from ..beans.x_property_change_listener import XPropertyChangeListener as XPropertyChangeListener_58e4105a
    from .line_descriptor import LineDescriptor as LineDescriptor_1e460eeb
    from .x_object_inspector_ui import XObjectInspectorUI as XObjectInspectorUI_5ccd1048
    from .x_property_control_factory import XPropertyControlFactory as XPropertyControlFactory_b8ed12ba
    from ..uno.x_interface import XInterface as XInterface_8f010a43
    from com.sun.star.beans.PropertyState import PropertyStateProto  # type: ignore
    from com.sun.star.inspection.InteractiveSelectionResult import InteractiveSelectionResultProto  # type: ignore

class XPropertyHandler(XComponent_98dc0ab5):
    """
    is the basic interface for object inspection.
    
    The ObjectInspector itself does not know anything about the object it is inspecting, all information is obtained via XPropertyHandlers. Also, property handlers are responsible for describing the user interface which should be used to interact with the user, with respect to a given aspect of the inspected component.
    
    **since**
    
        OOo 2.0.3

    See Also:
        `API XPropertyHandler <https://api.libreoffice.org/docs/idl/ref/interfacecom_1_1sun_1_1star_1_1inspection_1_1XPropertyHandler.html>`_
    """
    __ooo_ns__: str = 'com.sun.star.inspection'
    __ooo_full_ns__: str = 'com.sun.star.inspection.XPropertyHandler'
    __ooo_type_name__: str = 'interface'
    __pyunointerface__: str = 'com.sun.star.inspection.XPropertyHandler'

    @abstractmethod
    def actuatingPropertyChanged(self, ActuatingPropertyName: str, NewValue: object, OldValue: object, InspectorUI: XObjectInspectorUI_5ccd1048, FirstTimeInit: bool) -> None:
        """
        updates the UI of dependent properties when the value of a certain actuating property changed
        
        This method is called whenever a property value changes, limited to those properties whose changes the handler expressed interest in (see getActuatingProperties()).

        Raises:
            com.sun.star.lang.NullPointerException: ``NullPointerException``
        """
        ...
    @abstractmethod
    def addPropertyChangeListener(self, Listener: XPropertyChangeListener_58e4105a) -> None:
        """
        registers a listener for notification about property value changes
        
        An XPropertyHandler implementation might decide to ignore this call. However, in this case property value changes made by third party components are not reflected in the object inspector.
        
        If a handler implementation supports property change listeners, it must be able to cope with a call to addPropertyChangeListener() even if currently no component is being inspected. In this case, the listener must become active as soon as a new introspection is set in the next inspect() call.

        Raises:
            com.sun.star.lang.NullPointerException: ``NullPointerException``
        """
        ...
    @abstractmethod
    def convertToControlValue(self, PropertyName: str, PropertyValue: object, ControlValueType: object) -> object:
        """
        converts a given property value to a control-compatible value
        
        In describePropertyLine(), a property handler declared which type of control should be used to display the value of a certain property. To allow to use the same control type for different properties, and in particular, for properties of different type, conversions between controls values and property values are needed.
        
        This method converts a property value, which has previously been obtained using getPropertyValue(), into a control-compatible value, which can be used with XPropertyControl's XPropertyControl.Value attribute.
        
        A usual application of this method are list boxes: There is a generic list box implementation, which is able to display a simple list of strings. Usually, every string represents one possible property value. To translate between those property values and the displayed strings, convertToControlValue() and convertToPropertyValue() are used.
        
        The method is not invoked if the control's value type (XPropertyControl.ValueType equals the property's value type.

        Raises:
            com.sun.star.beans.UnknownPropertyException: ``UnknownPropertyException``
        """
        ...
    @abstractmethod
    def convertToPropertyValue(self, PropertyName: str, ControlValue: object) -> object:
        """
        converts a given control-compatible value to a property value
        
        In describePropertyLine(), a property handler declared which type of control should be used to display the value of a certain property. To allow to use the same control type for different properties, and in particular, for properties of different type, conversions between controls values and property values are needed.
        
        This method converts a control value into a property value, which subsequently can be used in conjunction with setPropertyValue().

        Raises:
            com.sun.star.beans.UnknownPropertyException: ``UnknownPropertyException``
        """
        ...
    @abstractmethod
    def describePropertyLine(self, PropertyName: str, ControlFactory: XPropertyControlFactory_b8ed12ba) -> LineDescriptor_1e460eeb:
        """
        describes the UI to be used to represent the property

        Raises:
            com.sun.star.beans.UnknownPropertyException: ``UnknownPropertyException``
            com.sun.star.lang.NullPointerException: ``NullPointerException``
        """
        ...
    @abstractmethod
    def getActuatingProperties(self) -> typing.Tuple[str, ...]:
        """
        retrieve the actuating properties which this handler is interested in
        
        In general, properties can be declared as \"actuating\", that is, when their value changes, the UI for other properties needs to be updated (e.g. enabled or disabled).
        
        With this method, a handler can declare that it feels responsible for some/all of the depending properties of certain actuating properties.
        
        Whenever the value of an actuating property changes, all handlers which expressed their interest in this particular actuating properties are called with their actuatingPropertyChanged() method.
        
        If getSupportedProperties() returned an empty sequence, this method will not be called
        """
        ...
    @abstractmethod
    def getPropertyState(self, PropertyName: str) -> PropertyStateProto:
        """
        returns the state of a property

        Raises:
            com.sun.star.beans.UnknownPropertyException: ``UnknownPropertyException``
        """
        ...
    @abstractmethod
    def getPropertyValue(self, PropertyName: str) -> object:
        """
        retrieves the current value of a property

        Raises:
            com.sun.star.beans.UnknownPropertyException: ``UnknownPropertyException``
        """
        ...
    @abstractmethod
    def getSupersededProperties(self) -> typing.Tuple[str, ...]:
        """
        returns the properties which are to be superseded by this handler
        
        Besides defining an own set of properties (see getSupportedProperties()), a property handler can also declare that foreign properties (which it is not responsible for) are superseded by its own properties.
        
        This is usually used if your handler is used with another, more generic one, which should continue to be responsible for all properties, except a few which your handler handles more elegantly.
        
        In such a case, simply return those properties here.
        
        There is a precedence in the property handlers used by an ObjectInspector, which also is important for the superseded properties. This precedence is implied by the precedence of factories to create the property handlers, as denoted in the XObjectInspectorModel.HandlerFactories attribute.
        
        With this in mind, property handlers can only supersede properties which are supported by a handler preceding them, but not properties of handlers succeeding them.
        
        For instance, imaging an XObjectInspectorModel which provides three factories, for handler A, B, and C - in this order. Now if A supports the property Foo, C supports Bar, and B supersedes both Foo and Bar, them the result is Bar is still present. This is because B precedes C, so it cannot, by definition, supersede properties which are supported by C.
        
        If getSupportedProperties() returned an empty sequence, this method will not be called.
        """
        ...
    @abstractmethod
    def getSupportedProperties(self) -> typing.Tuple[Property_8f4e0a76, ...]:
        """
        returns the properties which the handler can handle
        
        A handler is allowed to return an empty sequence here, indicating that for the given introspection, no properties handling can be provided. This might happen when a fixed set of property handlers is used for a variety of components to inspect, where not all handlers can really cope with all components.
        
        In the case of returning an empty sequence here, the property handler is ignored by all further processing in the object inspector.
        """
        ...
    @abstractmethod
    def inspect(self, Component: XInterface_8f010a43) -> None:
        """
        binds the property handler to a new component

        Raises:
            com.sun.star.lang.NullPointerException: ``NullPointerException``
        """
        ...
    @abstractmethod
    def isComposable(self, PropertyName: str) -> bool:
        """
        determines whether a given property, which the handler is responsible for, is composable.
        
        An object inspector can inspect multiple components at once, displaying the intersection of their properties. For this, all components are examined for their properties, and all properties which exist for all components, and are declared to be composable by their respective handler, are displayed in the inspector UI.

        Raises:
            com.sun.star.beans.UnknownPropertyException: ``UnknownPropertyException``
        """
        ...
    @abstractmethod
    def onInteractivePropertySelection(self, PropertyName: str, Primary: bool, outData: object, InspectorUI: XObjectInspectorUI_5ccd1048) -> InteractiveSelectionResultProto:
        """
        called when a browse button belonging to a property UI representation has been clicked
        
        Property handlers can raise a dedicated UI for entering or somehow changing a property value. Usually, this will be a modal dialog, but it can also be a non-modal user interface component.
        
        Availability of this feature is indicated by the LineDescriptor.HasPrimaryButton and LineDescriptor.HasSecondaryButton members of a LineDescriptor, which the XPropertyHandler fills in its describePropertyLine() method.
        
        When this method is called, the property handler should raise the UI needed to enter the property value, and return the result of this (see InteractiveSelectionResult).
        
        It is recommended that property handlers do not directly set the property value which has been obtained from the user, but store it in the output-parameter Data, and return InteractiveSelectionResult.ObtainedValue.
        
        If a handler sets the new property value directly, and returns InteractiveSelectionResult.ObtainedValue, this implies that the property cannot properly be handled in case the object inspector is inspecting an intersection of multiple components, since in this case onInteractivePropertySelection() will be called at one handler only, however the new property would have to be forwarded to all handlers.
        
        If a property is not composable, directly setting the new property value does not yield any problem, as long as property listeners are properly notified of the change.

        * ``outData`` is an out direction argument.

        Raises:
            com.sun.star.beans.UnknownPropertyException: ``UnknownPropertyException``
            com.sun.star.lang.NullPointerException: ``NullPointerException``
        """
        ...
    @abstractmethod
    def removePropertyChangeListener(self, Listener: XPropertyChangeListener_58e4105a) -> None:
        """
        revokes a listener for notification about property value changes
        """
        ...
    @abstractmethod
    def setPropertyValue(self, PropertyName: str, Value: object) -> None:
        """
        sets the value of a property

        Raises:
            com.sun.star.beans.UnknownPropertyException: ``UnknownPropertyException``
            com.sun.star.beans.PropertyVetoException: ``PropertyVetoException``
        """
        ...
    @abstractmethod
    def suspend(self, Suspend: bool) -> bool:
        """
        suspends the handler
        
        A XPropertyHandler is used by a XObjectInspector instance, which implements the XController interface. By definition, a XObjectInspector always forwards all suspend requests (com.sun.star.frame.XController.suspend()) to all its handlers.
        
        The usual use case for this method are non-modal user interface components used for property value input. Such a component might have been opened during onInteractivePropertySelection(). If a property handler receives a suspend() call, it should forward the suspension request to the UI component, and veto suspension of the XObjectInspector as appropriate.
        
        If suspension is not to be vetoed, then all non-modal UI components opened by the handler should have been closed when it returns from the suspend() call.
        """
        ...

__all__ = ['XPropertyHandler']



# coding: utf-8
#
# Copyright 2023 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Const Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.4
# Namespace: com.sun.star.embed


class EmbedVerbs(object):
    """
    Const Class

    This constants set contains possible verbs for a contained object.

    See Also:
        `API EmbedVerbs <https://api.libreoffice.org/docs/idl/ref/namespacecom_1_1sun_1_1star_1_1embed_1_1EmbedVerbs.html>`_
    """
    __ooo_ns__: str = 'com.sun.star.embed'
    __ooo_full_ns__: str = 'com.sun.star.embed.EmbedVerbs'
    __ooo_type_name__: str = 'const'

    MS_OLEVERB_PRIMARY = 0
    """
    lets the object do default activation, as by double-click.
    """
    MS_OLEVERB_SHOW = -1
    """
    lets the object open itself for editing or viewing.
    """
    MS_OLEVERB_OPEN = -2
    """
    lets the object activate itself outplace.
    """
    MS_OLEVERB_HIDE = -3
    """
    lets the inplace object remove its UI from container.
    """
    MS_OLEVERB_UIACTIVATE = -4
    """
    lets the object proceed with UI activation.
    """
    MS_OLEVERB_IPACTIVATE = -5
    """
    lets the object activate itself inplace.
    """
    MS_OLEVERB_DISCARDUNDOSTATE = -6
    """
    lets the object forget any undo state.
    """

__all__ = ['EmbedVerbs']



# coding: utf-8
#
# Copyright 2023 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Const Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.4
# Namespace: com.sun.star.embed
import uno
from enum import IntEnum
from typing import TYPE_CHECKING
from ooo.oenv.env_const import UNO_ENVIRONMENT, UNO_RUNTIME

_DYNAMIC = False
if (not TYPE_CHECKING) and UNO_RUNTIME and UNO_ENVIRONMENT:
    _DYNAMIC = True

if not TYPE_CHECKING and _DYNAMIC:
    # document generators will most likely not see this.
    from ooo.helper.enum_helper import UnoConstMeta, ConstEnumMeta

    class EmbedMapUnits(metaclass=UnoConstMeta, type_name="com.sun.star.embed.EmbedMapUnits", name_space="com.sun.star.embed"):
        """Dynamic Class. Contains all the constant values of ``com.sun.star.embed.EmbedMapUnits``"""
        pass

    class EmbedMapUnitsEnum(IntEnum, metaclass=ConstEnumMeta, type_name="com.sun.star.embed.EmbedMapUnits", name_space="com.sun.star.embed"):
        """Dynamic Enum. Contains all the constant values of ``com.sun.star.embed.EmbedMapUnits`` as Enum values"""
        pass

else:
    if TYPE_CHECKING:
        from com.sun.star.embed import EmbedMapUnits as EmbedMapUnits
    else:
        # keep document generators happy
        from ...lo.embed.embed_map_units import EmbedMapUnits as EmbedMapUnits

    class EmbedMapUnitsEnum(IntEnum):
        """
        Enum of Const Class EmbedMapUnits

        contains list of possible map modes supported by embedded object.
        """
        ONE_100TH_MM = EmbedMapUnits.ONE_100TH_MM
        """
        In this type of map mode one logical point is equal to one-hundredth of millimeter.
        """
        ONE_10TH_MM = EmbedMapUnits.ONE_10TH_MM
        """
        In this type of map mode one logical point is equal to one-tenth of millimeter.
        """
        ONE_MM = EmbedMapUnits.ONE_MM
        """
        In this type of map mode one logical point is equal to one millimeter.
        """
        ONE_CM = EmbedMapUnits.ONE_CM
        """
        In this type of map mode one logical point is equal to one centimeter.
        """
        ONE_1000TH_INCH = EmbedMapUnits.ONE_1000TH_INCH
        """
        In this type of map mode one logical point is equal to one-thousandth of inch.
        """
        ONE_100TH_INCH = EmbedMapUnits.ONE_100TH_INCH
        """
        In this type of map mode one logical point is equal to one-hundredth of inch.
        """
        ONE_10TH_INCH = EmbedMapUnits.ONE_10TH_INCH
        """
        In this type of map mode one logical point is equal to one-tenth of inch.
        """
        ONE_INCH = EmbedMapUnits.ONE_INCH
        """
        In this type of map mode one logical point is equal to one inch.
        """
        POINT = EmbedMapUnits.POINT
        """
        In this type of map mode one logical point is equal to one typographical point.
        """
        TWIP = EmbedMapUnits.TWIP
        """
        In this type of map mode one logical point is equal to one twentieth of typographical point.
        """
        PIXEL = EmbedMapUnits.PIXEL
        """
        In this type of map mode one logical point is equal to one pixel.
        """

__all__ = ['EmbedMapUnits', 'EmbedMapUnitsEnum']



# coding: utf-8
#
# Copyright 2023 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Interface Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.4
# Namespace: com.sun.star.mozilla
from __future__ import annotations
import typing
from abc import abstractmethod
from ..lang.x_component import XComponent as XComponent_98dc0ab5
if typing.TYPE_CHECKING:
    from .x_menu_proxy_listener import XMenuProxyListener as XMenuProxyListener_2ccf0f55

class XMenuProxy(XComponent_98dc0ab5):
    """
    Allows to execute dispatch for a menu item and handles listeners for changes in menu items.

    See Also:
        `API XMenuProxy <https://api.libreoffice.org/docs/idl/ref/interfacecom_1_1sun_1_1star_1_1mozilla_1_1XMenuProxy.html>`_
    """
    __ooo_ns__: str = 'com.sun.star.mozilla'
    __ooo_full_ns__: str = 'com.sun.star.mozilla.XMenuProxy'
    __ooo_type_name__: str = 'interface'
    __pyunointerface__: str = 'com.sun.star.mozilla.XMenuProxy'

    @abstractmethod
    def addMenuProxyListener(self, xListener: XMenuProxyListener_2ccf0f55) -> None:
        """
        Registers an event listener, which will be called when the menu changes.
        """
        ...
    @abstractmethod
    def executeMenuItem(self, ID: int) -> None:
        """
        Executes dispatch for the given menu id.
        """
        ...
    @abstractmethod
    def removeMenuProxyListener(self, xListener: XMenuProxyListener_2ccf0f55) -> None:
        """
        Unregisters an event listener which was registered with XMenuProxy.addMenuProxyListener().
        """
        ...

__all__ = ['XMenuProxy']





# coding: utf-8
#
# Copyright 2023 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Struct Class
# this is a auto generated file generated by Cheetah
# Namespace: com.sun.star.text
# Libre Office Version: 7.4
from ooo.oenv.env_const import UNO_NONE
import typing


class SectionFileLink(object):
    """
    Struct Class

    describes the link for a text section.
    
    If the URL is an empty string, then the section is not linked.
    
    The bookmark of the URL (after the \"#\") is the name of a bookmark or a section name in the linked document. If a bookmark or section with this name exists in the document, then only this part is linked into the given text section.
    
    SectionFileLink.FilterName is the internal name of the document filter. To use this struct, it is not necessary to set SectionFileLink.FilterName. It will be automatically assigned.

    See Also:
        `API SectionFileLink <https://api.libreoffice.org/docs/idl/ref/structcom_1_1sun_1_1star_1_1text_1_1SectionFileLink.html>`_
    """
    __ooo_ns__: str = 'com.sun.star.text'
    __ooo_full_ns__: str = 'com.sun.star.text.SectionFileLink'
    __ooo_type_name__: str = 'struct'
    typeName: str = 'com.sun.star.text.SectionFileLink'
    """Literal Constant ``com.sun.star.text.SectionFileLink``"""

    def __init__(self, FileURL: typing.Optional[str] = '', FilterName: typing.Optional[str] = '') -> None:
        """
        Constructor

        Arguments:
            FileURL (str, optional): FileURL value.
            FilterName (str, optional): FilterName value.
        """
        super().__init__()

        if isinstance(FileURL, SectionFileLink):
            oth: SectionFileLink = FileURL
            self.FileURL = oth.FileURL
            self.FilterName = oth.FilterName
            return

        kargs = {
            "FileURL": FileURL,
            "FilterName": FilterName,
        }
        self._init(**kargs)

    def _init(self, **kwargs) -> None:
        self._file_url = kwargs["FileURL"]
        self._filter_name = kwargs["FilterName"]


    @property
    def FileURL(self) -> str:
        """
        contains the URL of the linked file.
        """
        return self._file_url

    @FileURL.setter
    def FileURL(self, value: str) -> None:
        self._file_url = value

    @property
    def FilterName(self) -> str:
        """
        contains the name of the file filter that is used to load the linked file.
        """
        return self._filter_name

    @FilterName.setter
    def FilterName(self, value: str) -> None:
        self._filter_name = value


__all__ = ['SectionFileLink']
